/* Autogen header for Unicorn Engine - DONOT MODIFY */
#ifndef UNICORN_AUTOGEN_ppc64_H
#define UNICORN_AUTOGEN_ppc64_H
#ifndef UNICORN_ARCH_POSTFIX
#define UNICORN_ARCH_POSTFIX _ppc64
#endif
#define gen_helper_check_exit_request gen_helper_check_exit_request_ppc64
#define unicorn_fill_tlb unicorn_fill_tlb_ppc64
#define reg_read reg_read_ppc64
#define reg_write reg_write_ppc64
#define uc_init uc_init_ppc64
#define uc_add_inline_hook uc_add_inline_hook_ppc64
#define uc_del_inline_hook uc_del_inline_hook_ppc64
#define tb_invalidate_phys_range tb_invalidate_phys_range_ppc64
#define use_idiv_instructions use_idiv_instructions_ppc64
#define arm_arch arm_arch_ppc64
#define tb_target_set_jmp_target tb_target_set_jmp_target_ppc64
#define have_bmi1 have_bmi1_ppc64
#define have_popcnt have_popcnt_ppc64
#define have_avx1 have_avx1_ppc64
#define have_avx2 have_avx2_ppc64
#define have_isa have_isa_ppc64
#define have_altivec have_altivec_ppc64
#define have_vsx have_vsx_ppc64
#define flush_icache_range flush_icache_range_ppc64
#define s390_facilities s390_facilities_ppc64
#define tcg_dump_op tcg_dump_op_ppc64
#define tcg_dump_ops tcg_dump_ops_ppc64
#define tcg_gen_and_i64 tcg_gen_and_i64_ppc64
#define tcg_gen_discard_i64 tcg_gen_discard_i64_ppc64
#define tcg_gen_ld16s_i64 tcg_gen_ld16s_i64_ppc64
#define tcg_gen_ld16u_i64 tcg_gen_ld16u_i64_ppc64
#define tcg_gen_ld32s_i64 tcg_gen_ld32s_i64_ppc64
#define tcg_gen_ld32u_i64 tcg_gen_ld32u_i64_ppc64
#define tcg_gen_ld8s_i64 tcg_gen_ld8s_i64_ppc64
#define tcg_gen_ld8u_i64 tcg_gen_ld8u_i64_ppc64
#define tcg_gen_ld_i64 tcg_gen_ld_i64_ppc64
#define tcg_gen_mov_i64 tcg_gen_mov_i64_ppc64
#define tcg_gen_movi_i64 tcg_gen_movi_i64_ppc64
#define tcg_gen_mul_i64 tcg_gen_mul_i64_ppc64
#define tcg_gen_or_i64 tcg_gen_or_i64_ppc64
#define tcg_gen_sar_i64 tcg_gen_sar_i64_ppc64
#define tcg_gen_shl_i64 tcg_gen_shl_i64_ppc64
#define tcg_gen_shr_i64 tcg_gen_shr_i64_ppc64
#define tcg_gen_st_i64 tcg_gen_st_i64_ppc64
#define tcg_gen_xor_i64 tcg_gen_xor_i64_ppc64
#define cpu_icount_to_ns cpu_icount_to_ns_ppc64
#define cpu_is_stopped cpu_is_stopped_ppc64
#define cpu_get_ticks cpu_get_ticks_ppc64
#define cpu_get_clock cpu_get_clock_ppc64
#define cpu_resume cpu_resume_ppc64
#define qemu_init_vcpu qemu_init_vcpu_ppc64
#define cpu_stop_current cpu_stop_current_ppc64
#define resume_all_vcpus resume_all_vcpus_ppc64
#define vm_start vm_start_ppc64
#define address_space_dispatch_compact address_space_dispatch_compact_ppc64
#define flatview_translate flatview_translate_ppc64
#define flatview_copy flatview_copy_ppc64
#define address_space_translate_for_iotlb address_space_translate_for_iotlb_ppc64
#define qemu_get_cpu qemu_get_cpu_ppc64
#define cpu_address_space_init cpu_address_space_init_ppc64
#define cpu_get_address_space cpu_get_address_space_ppc64
#define cpu_exec_unrealizefn cpu_exec_unrealizefn_ppc64
#define cpu_exec_initfn cpu_exec_initfn_ppc64
#define cpu_exec_realizefn cpu_exec_realizefn_ppc64
#define tb_invalidate_phys_addr tb_invalidate_phys_addr_ppc64
#define cpu_watchpoint_insert cpu_watchpoint_insert_ppc64
#define cpu_watchpoint_remove_by_ref cpu_watchpoint_remove_by_ref_ppc64
#define cpu_watchpoint_remove_all cpu_watchpoint_remove_all_ppc64
#define cpu_watchpoint_address_matches cpu_watchpoint_address_matches_ppc64
#define cpu_breakpoint_insert cpu_breakpoint_insert_ppc64
#define cpu_breakpoint_remove cpu_breakpoint_remove_ppc64
#define cpu_breakpoint_remove_by_ref cpu_breakpoint_remove_by_ref_ppc64
#define cpu_breakpoint_remove_all cpu_breakpoint_remove_all_ppc64
#define cpu_abort cpu_abort_ppc64
#define cpu_physical_memory_test_and_clear_dirty cpu_physical_memory_test_and_clear_dirty_ppc64
#define memory_region_section_get_iotlb memory_region_section_get_iotlb_ppc64
#define flatview_add_to_dispatch flatview_add_to_dispatch_ppc64
#define qemu_ram_get_host_addr qemu_ram_get_host_addr_ppc64
#define qemu_ram_get_offset qemu_ram_get_offset_ppc64
#define qemu_ram_get_used_length qemu_ram_get_used_length_ppc64
#define qemu_ram_is_shared qemu_ram_is_shared_ppc64
#define qemu_ram_pagesize qemu_ram_pagesize_ppc64
#define qemu_ram_alloc_from_ptr qemu_ram_alloc_from_ptr_ppc64
#define qemu_ram_alloc qemu_ram_alloc_ppc64
#define qemu_ram_free qemu_ram_free_ppc64
#define qemu_map_ram_ptr qemu_map_ram_ptr_ppc64
#define qemu_ram_block_host_offset qemu_ram_block_host_offset_ppc64
#define qemu_ram_block_from_host qemu_ram_block_from_host_ppc64
#define qemu_ram_addr_from_host qemu_ram_addr_from_host_ppc64
#define cpu_check_watchpoint cpu_check_watchpoint_ppc64
#define iotlb_to_section iotlb_to_section_ppc64
#define address_space_dispatch_new address_space_dispatch_new_ppc64
#define address_space_dispatch_free address_space_dispatch_free_ppc64
#define address_space_dispatch_clear address_space_dispatch_clear_ppc64
#define flatview_read_continue flatview_read_continue_ppc64
#define address_space_read_full address_space_read_full_ppc64
#define address_space_write address_space_write_ppc64
#define address_space_rw address_space_rw_ppc64
#define cpu_physical_memory_rw cpu_physical_memory_rw_ppc64
#define address_space_write_rom address_space_write_rom_ppc64
#define cpu_flush_icache_range cpu_flush_icache_range_ppc64
#define cpu_exec_init_all cpu_exec_init_all_ppc64
#define address_space_access_valid address_space_access_valid_ppc64
#define address_space_map address_space_map_ppc64
#define address_space_unmap address_space_unmap_ppc64
#define cpu_physical_memory_map cpu_physical_memory_map_ppc64
#define cpu_physical_memory_unmap cpu_physical_memory_unmap_ppc64
#define cpu_memory_rw_debug cpu_memory_rw_debug_ppc64
#define qemu_target_page_size qemu_target_page_size_ppc64
#define qemu_target_page_bits qemu_target_page_bits_ppc64
#define qemu_target_page_bits_min qemu_target_page_bits_min_ppc64
#define target_words_bigendian target_words_bigendian_ppc64
#define cpu_physical_memory_is_io cpu_physical_memory_is_io_ppc64
#define ram_block_discard_range ram_block_discard_range_ppc64
#define ramblock_is_pmem ramblock_is_pmem_ppc64
#define page_size_init page_size_init_ppc64
#define set_preferred_target_page_bits set_preferred_target_page_bits_ppc64
#define finalize_target_page_bits finalize_target_page_bits_ppc64
#define cpu_outb cpu_outb_ppc64
#define cpu_outw cpu_outw_ppc64
#define cpu_outl cpu_outl_ppc64
#define cpu_inb cpu_inb_ppc64
#define cpu_inw cpu_inw_ppc64
#define cpu_inl cpu_inl_ppc64
#define memory_map memory_map_ppc64
#define memory_map_io memory_map_io_ppc64
#define memory_map_ptr memory_map_ptr_ppc64
#define memory_cow memory_cow_ppc64
#define memory_unmap memory_unmap_ppc64
#define memory_moveout memory_moveout_ppc64
#define memory_movein memory_movein_ppc64
#define memory_free memory_free_ppc64
#define flatview_unref flatview_unref_ppc64
#define address_space_get_flatview address_space_get_flatview_ppc64
#define memory_region_transaction_begin memory_region_transaction_begin_ppc64
#define memory_region_transaction_commit memory_region_transaction_commit_ppc64
#define memory_region_init memory_region_init_ppc64
#define memory_region_access_valid memory_region_access_valid_ppc64
#define memory_region_dispatch_read memory_region_dispatch_read_ppc64
#define memory_region_dispatch_write memory_region_dispatch_write_ppc64
#define memory_region_init_io memory_region_init_io_ppc64
#define memory_region_init_ram_ptr memory_region_init_ram_ptr_ppc64
#define memory_region_size memory_region_size_ppc64
#define memory_region_set_readonly memory_region_set_readonly_ppc64
#define memory_region_get_ram_ptr memory_region_get_ram_ptr_ppc64
#define memory_region_from_host memory_region_from_host_ppc64
#define memory_region_get_ram_addr memory_region_get_ram_addr_ppc64
#define memory_region_add_subregion memory_region_add_subregion_ppc64
#define memory_region_del_subregion memory_region_del_subregion_ppc64
#define memory_region_add_subregion_overlap memory_region_add_subregion_overlap_ppc64
#define memory_region_find memory_region_find_ppc64
#define memory_region_filter_subregions memory_region_filter_subregions_ppc64
#define memory_listener_register memory_listener_register_ppc64
#define memory_listener_unregister memory_listener_unregister_ppc64
#define address_space_remove_listeners address_space_remove_listeners_ppc64
#define address_space_init address_space_init_ppc64
#define address_space_destroy address_space_destroy_ppc64
#define memory_region_init_ram memory_region_init_ram_ppc64
#define memory_mapping_list_add_merge_sorted memory_mapping_list_add_merge_sorted_ppc64
#define find_memory_mapping find_memory_mapping_ppc64
#define exec_inline_op exec_inline_op_ppc64
#define floatx80_default_nan floatx80_default_nan_ppc64
#define float_raise float_raise_ppc64
#define float16_is_quiet_nan float16_is_quiet_nan_ppc64
#define float16_is_signaling_nan float16_is_signaling_nan_ppc64
#define float32_is_quiet_nan float32_is_quiet_nan_ppc64
#define float32_is_signaling_nan float32_is_signaling_nan_ppc64
#define float64_is_quiet_nan float64_is_quiet_nan_ppc64
#define float64_is_signaling_nan float64_is_signaling_nan_ppc64
#define floatx80_is_quiet_nan floatx80_is_quiet_nan_ppc64
#define floatx80_is_signaling_nan floatx80_is_signaling_nan_ppc64
#define floatx80_silence_nan floatx80_silence_nan_ppc64
#define propagateFloatx80NaN propagateFloatx80NaN_ppc64
#define float128_is_quiet_nan float128_is_quiet_nan_ppc64
#define float128_is_signaling_nan float128_is_signaling_nan_ppc64
#define float128_silence_nan float128_silence_nan_ppc64
#define float16_add float16_add_ppc64
#define float16_sub float16_sub_ppc64
#define float32_add float32_add_ppc64
#define float32_sub float32_sub_ppc64
#define float64_add float64_add_ppc64
#define float64_sub float64_sub_ppc64
#define float16_mul float16_mul_ppc64
#define float32_mul float32_mul_ppc64
#define float64_mul float64_mul_ppc64
#define float16_muladd float16_muladd_ppc64
#define float32_muladd float32_muladd_ppc64
#define float64_muladd float64_muladd_ppc64
#define float16_div float16_div_ppc64
#define float32_div float32_div_ppc64
#define float64_div float64_div_ppc64
#define float16_to_float32 float16_to_float32_ppc64
#define float16_to_float64 float16_to_float64_ppc64
#define float32_to_float16 float32_to_float16_ppc64
#define float32_to_float64 float32_to_float64_ppc64
#define float64_to_float16 float64_to_float16_ppc64
#define float64_to_float32 float64_to_float32_ppc64
#define float16_round_to_int float16_round_to_int_ppc64
#define float32_round_to_int float32_round_to_int_ppc64
#define float64_round_to_int float64_round_to_int_ppc64
#define float16_to_int16_scalbn float16_to_int16_scalbn_ppc64
#define float16_to_int32_scalbn float16_to_int32_scalbn_ppc64
#define float16_to_int64_scalbn float16_to_int64_scalbn_ppc64
#define float32_to_int16_scalbn float32_to_int16_scalbn_ppc64
#define float32_to_int32_scalbn float32_to_int32_scalbn_ppc64
#define float32_to_int64_scalbn float32_to_int64_scalbn_ppc64
#define float64_to_int16_scalbn float64_to_int16_scalbn_ppc64
#define float64_to_int32_scalbn float64_to_int32_scalbn_ppc64
#define float64_to_int64_scalbn float64_to_int64_scalbn_ppc64
#define float16_to_int16 float16_to_int16_ppc64
#define float16_to_int32 float16_to_int32_ppc64
#define float16_to_int64 float16_to_int64_ppc64
#define float32_to_int16 float32_to_int16_ppc64
#define float32_to_int32 float32_to_int32_ppc64
#define float32_to_int64 float32_to_int64_ppc64
#define float64_to_int16 float64_to_int16_ppc64
#define float64_to_int32 float64_to_int32_ppc64
#define float64_to_int64 float64_to_int64_ppc64
#define float16_to_int16_round_to_zero float16_to_int16_round_to_zero_ppc64
#define float16_to_int32_round_to_zero float16_to_int32_round_to_zero_ppc64
#define float16_to_int64_round_to_zero float16_to_int64_round_to_zero_ppc64
#define float32_to_int16_round_to_zero float32_to_int16_round_to_zero_ppc64
#define float32_to_int32_round_to_zero float32_to_int32_round_to_zero_ppc64
#define float32_to_int64_round_to_zero float32_to_int64_round_to_zero_ppc64
#define float64_to_int16_round_to_zero float64_to_int16_round_to_zero_ppc64
#define float64_to_int32_round_to_zero float64_to_int32_round_to_zero_ppc64
#define float64_to_int64_round_to_zero float64_to_int64_round_to_zero_ppc64
#define float16_to_uint16_scalbn float16_to_uint16_scalbn_ppc64
#define float16_to_uint32_scalbn float16_to_uint32_scalbn_ppc64
#define float16_to_uint64_scalbn float16_to_uint64_scalbn_ppc64
#define float32_to_uint16_scalbn float32_to_uint16_scalbn_ppc64
#define float32_to_uint32_scalbn float32_to_uint32_scalbn_ppc64
#define float32_to_uint64_scalbn float32_to_uint64_scalbn_ppc64
#define float64_to_uint16_scalbn float64_to_uint16_scalbn_ppc64
#define float64_to_uint32_scalbn float64_to_uint32_scalbn_ppc64
#define float64_to_uint64_scalbn float64_to_uint64_scalbn_ppc64
#define float16_to_uint16 float16_to_uint16_ppc64
#define float16_to_uint32 float16_to_uint32_ppc64
#define float16_to_uint64 float16_to_uint64_ppc64
#define float32_to_uint16 float32_to_uint16_ppc64
#define float32_to_uint32 float32_to_uint32_ppc64
#define float32_to_uint64 float32_to_uint64_ppc64
#define float64_to_uint16 float64_to_uint16_ppc64
#define float64_to_uint32 float64_to_uint32_ppc64
#define float64_to_uint64 float64_to_uint64_ppc64
#define float16_to_uint16_round_to_zero float16_to_uint16_round_to_zero_ppc64
#define float16_to_uint32_round_to_zero float16_to_uint32_round_to_zero_ppc64
#define float16_to_uint64_round_to_zero float16_to_uint64_round_to_zero_ppc64
#define float32_to_uint16_round_to_zero float32_to_uint16_round_to_zero_ppc64
#define float32_to_uint32_round_to_zero float32_to_uint32_round_to_zero_ppc64
#define float32_to_uint64_round_to_zero float32_to_uint64_round_to_zero_ppc64
#define float64_to_uint16_round_to_zero float64_to_uint16_round_to_zero_ppc64
#define float64_to_uint32_round_to_zero float64_to_uint32_round_to_zero_ppc64
#define float64_to_uint64_round_to_zero float64_to_uint64_round_to_zero_ppc64
#define int64_to_float16_scalbn int64_to_float16_scalbn_ppc64
#define int32_to_float16_scalbn int32_to_float16_scalbn_ppc64
#define int16_to_float16_scalbn int16_to_float16_scalbn_ppc64
#define int64_to_float16 int64_to_float16_ppc64
#define int32_to_float16 int32_to_float16_ppc64
#define int16_to_float16 int16_to_float16_ppc64
#define int64_to_float32_scalbn int64_to_float32_scalbn_ppc64
#define int32_to_float32_scalbn int32_to_float32_scalbn_ppc64
#define int16_to_float32_scalbn int16_to_float32_scalbn_ppc64
#define int64_to_float32 int64_to_float32_ppc64
#define int32_to_float32 int32_to_float32_ppc64
#define int16_to_float32 int16_to_float32_ppc64
#define int64_to_float64_scalbn int64_to_float64_scalbn_ppc64
#define int32_to_float64_scalbn int32_to_float64_scalbn_ppc64
#define int16_to_float64_scalbn int16_to_float64_scalbn_ppc64
#define int64_to_float64 int64_to_float64_ppc64
#define int32_to_float64 int32_to_float64_ppc64
#define int16_to_float64 int16_to_float64_ppc64
#define uint64_to_float16_scalbn uint64_to_float16_scalbn_ppc64
#define uint32_to_float16_scalbn uint32_to_float16_scalbn_ppc64
#define uint16_to_float16_scalbn uint16_to_float16_scalbn_ppc64
#define uint64_to_float16 uint64_to_float16_ppc64
#define uint32_to_float16 uint32_to_float16_ppc64
#define uint16_to_float16 uint16_to_float16_ppc64
#define uint64_to_float32_scalbn uint64_to_float32_scalbn_ppc64
#define uint32_to_float32_scalbn uint32_to_float32_scalbn_ppc64
#define uint16_to_float32_scalbn uint16_to_float32_scalbn_ppc64
#define uint64_to_float32 uint64_to_float32_ppc64
#define uint32_to_float32 uint32_to_float32_ppc64
#define uint16_to_float32 uint16_to_float32_ppc64
#define uint64_to_float64_scalbn uint64_to_float64_scalbn_ppc64
#define uint32_to_float64_scalbn uint32_to_float64_scalbn_ppc64
#define uint16_to_float64_scalbn uint16_to_float64_scalbn_ppc64
#define uint64_to_float64 uint64_to_float64_ppc64
#define uint32_to_float64 uint32_to_float64_ppc64
#define uint16_to_float64 uint16_to_float64_ppc64
#define float16_min float16_min_ppc64
#define float16_minnum float16_minnum_ppc64
#define float16_minnummag float16_minnummag_ppc64
#define float16_max float16_max_ppc64
#define float16_maxnum float16_maxnum_ppc64
#define float16_maxnummag float16_maxnummag_ppc64
#define float32_min float32_min_ppc64
#define float32_minnum float32_minnum_ppc64
#define float32_minnummag float32_minnummag_ppc64
#define float32_max float32_max_ppc64
#define float32_maxnum float32_maxnum_ppc64
#define float32_maxnummag float32_maxnummag_ppc64
#define float64_min float64_min_ppc64
#define float64_minnum float64_minnum_ppc64
#define float64_minnummag float64_minnummag_ppc64
#define float64_max float64_max_ppc64
#define float64_maxnum float64_maxnum_ppc64
#define float64_maxnummag float64_maxnummag_ppc64
#define float16_compare float16_compare_ppc64
#define float16_compare_quiet float16_compare_quiet_ppc64
#define float32_compare float32_compare_ppc64
#define float32_compare_quiet float32_compare_quiet_ppc64
#define float64_compare float64_compare_ppc64
#define float64_compare_quiet float64_compare_quiet_ppc64
#define float16_scalbn float16_scalbn_ppc64
#define float32_scalbn float32_scalbn_ppc64
#define float64_scalbn float64_scalbn_ppc64
#define float16_sqrt float16_sqrt_ppc64
#define float32_sqrt float32_sqrt_ppc64
#define float64_sqrt float64_sqrt_ppc64
#define float16_default_nan float16_default_nan_ppc64
#define float32_default_nan float32_default_nan_ppc64
#define float64_default_nan float64_default_nan_ppc64
#define float128_default_nan float128_default_nan_ppc64
#define float16_silence_nan float16_silence_nan_ppc64
#define float32_silence_nan float32_silence_nan_ppc64
#define float64_silence_nan float64_silence_nan_ppc64
#define float16_squash_input_denormal float16_squash_input_denormal_ppc64
#define float32_squash_input_denormal float32_squash_input_denormal_ppc64
#define float64_squash_input_denormal float64_squash_input_denormal_ppc64
#define normalizeFloatx80Subnormal normalizeFloatx80Subnormal_ppc64
#define roundAndPackFloatx80 roundAndPackFloatx80_ppc64
#define normalizeRoundAndPackFloatx80 normalizeRoundAndPackFloatx80_ppc64
#define int32_to_floatx80 int32_to_floatx80_ppc64
#define int32_to_float128 int32_to_float128_ppc64
#define int64_to_floatx80 int64_to_floatx80_ppc64
#define int64_to_float128 int64_to_float128_ppc64
#define uint64_to_float128 uint64_to_float128_ppc64
#define float32_to_floatx80 float32_to_floatx80_ppc64
#define float32_to_float128 float32_to_float128_ppc64
#define float32_rem float32_rem_ppc64
#define float32_exp2 float32_exp2_ppc64
#define float32_log2 float32_log2_ppc64
#define float32_eq float32_eq_ppc64
#define float32_le float32_le_ppc64
#define float32_lt float32_lt_ppc64
#define float32_unordered float32_unordered_ppc64
#define float32_eq_quiet float32_eq_quiet_ppc64
#define float32_le_quiet float32_le_quiet_ppc64
#define float32_lt_quiet float32_lt_quiet_ppc64
#define float32_unordered_quiet float32_unordered_quiet_ppc64
#define float64_to_floatx80 float64_to_floatx80_ppc64
#define float64_to_float128 float64_to_float128_ppc64
#define float64_rem float64_rem_ppc64
#define float64_log2 float64_log2_ppc64
#define float64_eq float64_eq_ppc64
#define float64_le float64_le_ppc64
#define float64_lt float64_lt_ppc64
#define float64_unordered float64_unordered_ppc64
#define float64_eq_quiet float64_eq_quiet_ppc64
#define float64_le_quiet float64_le_quiet_ppc64
#define float64_lt_quiet float64_lt_quiet_ppc64
#define float64_unordered_quiet float64_unordered_quiet_ppc64
#define floatx80_to_int32 floatx80_to_int32_ppc64
#define floatx80_to_int32_round_to_zero floatx80_to_int32_round_to_zero_ppc64
#define floatx80_to_int64 floatx80_to_int64_ppc64
#define floatx80_to_int64_round_to_zero floatx80_to_int64_round_to_zero_ppc64
#define floatx80_to_float32 floatx80_to_float32_ppc64
#define floatx80_to_float64 floatx80_to_float64_ppc64
#define floatx80_to_float128 floatx80_to_float128_ppc64
#define floatx80_round floatx80_round_ppc64
#define floatx80_round_to_int floatx80_round_to_int_ppc64
#define floatx80_add floatx80_add_ppc64
#define floatx80_sub floatx80_sub_ppc64
#define floatx80_mul floatx80_mul_ppc64
#define floatx80_div floatx80_div_ppc64
#define floatx80_rem floatx80_rem_ppc64
#define floatx80_sqrt floatx80_sqrt_ppc64
#define floatx80_eq floatx80_eq_ppc64
#define floatx80_le floatx80_le_ppc64
#define floatx80_lt floatx80_lt_ppc64
#define floatx80_unordered floatx80_unordered_ppc64
#define floatx80_eq_quiet floatx80_eq_quiet_ppc64
#define floatx80_le_quiet floatx80_le_quiet_ppc64
#define floatx80_lt_quiet floatx80_lt_quiet_ppc64
#define floatx80_unordered_quiet floatx80_unordered_quiet_ppc64
#define float128_to_int32 float128_to_int32_ppc64
#define float128_to_int32_round_to_zero float128_to_int32_round_to_zero_ppc64
#define float128_to_int64 float128_to_int64_ppc64
#define float128_to_int64_round_to_zero float128_to_int64_round_to_zero_ppc64
#define float128_to_uint64 float128_to_uint64_ppc64
#define float128_to_uint64_round_to_zero float128_to_uint64_round_to_zero_ppc64
#define float128_to_uint32_round_to_zero float128_to_uint32_round_to_zero_ppc64
#define float128_to_uint32 float128_to_uint32_ppc64
#define float128_to_float32 float128_to_float32_ppc64
#define float128_to_float64 float128_to_float64_ppc64
#define float128_to_floatx80 float128_to_floatx80_ppc64
#define float128_round_to_int float128_round_to_int_ppc64
#define float128_add float128_add_ppc64
#define float128_sub float128_sub_ppc64
#define float128_mul float128_mul_ppc64
#define float128_div float128_div_ppc64
#define float128_rem float128_rem_ppc64
#define float128_sqrt float128_sqrt_ppc64
#define float128_eq float128_eq_ppc64
#define float128_le float128_le_ppc64
#define float128_lt float128_lt_ppc64
#define float128_unordered float128_unordered_ppc64
#define float128_eq_quiet float128_eq_quiet_ppc64
#define float128_le_quiet float128_le_quiet_ppc64
#define float128_lt_quiet float128_lt_quiet_ppc64
#define float128_unordered_quiet float128_unordered_quiet_ppc64
#define floatx80_compare floatx80_compare_ppc64
#define floatx80_compare_quiet floatx80_compare_quiet_ppc64
#define float128_compare float128_compare_ppc64
#define float128_compare_quiet float128_compare_quiet_ppc64
#define floatx80_scalbn floatx80_scalbn_ppc64
#define float128_scalbn float128_scalbn_ppc64
#define softfloat_init softfloat_init_ppc64
#define tcg_optimize tcg_optimize_ppc64
#define gen_new_label gen_new_label_ppc64
#define tcg_can_emit_vec_op tcg_can_emit_vec_op_ppc64
#define tcg_expand_vec_op tcg_expand_vec_op_ppc64
#define tcg_register_jit tcg_register_jit_ppc64
#define tcg_tb_insert tcg_tb_insert_ppc64
#define tcg_tb_remove tcg_tb_remove_ppc64
#define tcg_tb_lookup tcg_tb_lookup_ppc64
#define tcg_tb_foreach tcg_tb_foreach_ppc64
#define tcg_nb_tbs tcg_nb_tbs_ppc64
#define tcg_region_reset_all tcg_region_reset_all_ppc64
#define tcg_region_init tcg_region_init_ppc64
#define tcg_code_size tcg_code_size_ppc64
#define tcg_code_capacity tcg_code_capacity_ppc64
#define tcg_tb_phys_invalidate_count tcg_tb_phys_invalidate_count_ppc64
#define tcg_malloc_internal tcg_malloc_internal_ppc64
#define tcg_pool_reset tcg_pool_reset_ppc64
#define tcg_context_init tcg_context_init_ppc64
#define tcg_tb_alloc tcg_tb_alloc_ppc64
#define tcg_prologue_init tcg_prologue_init_ppc64
#define tcg_func_start tcg_func_start_ppc64
#define tcg_set_frame tcg_set_frame_ppc64
#define tcg_global_mem_new_internal tcg_global_mem_new_internal_ppc64
#define tcg_temp_new_internal tcg_temp_new_internal_ppc64
#define tcg_temp_new_vec tcg_temp_new_vec_ppc64
#define tcg_temp_new_vec_matching tcg_temp_new_vec_matching_ppc64
#define tcg_temp_free_internal tcg_temp_free_internal_ppc64
#define tcg_const_i32 tcg_const_i32_ppc64
#define tcg_const_i64 tcg_const_i64_ppc64
#define tcg_const_local_i32 tcg_const_local_i32_ppc64
#define tcg_const_local_i64 tcg_const_local_i64_ppc64
#define tcg_op_supported tcg_op_supported_ppc64
#define tcg_gen_callN tcg_gen_callN_ppc64
#define tcg_op_remove tcg_op_remove_ppc64
#define tcg_emit_op tcg_emit_op_ppc64
#define tcg_op_insert_before tcg_op_insert_before_ppc64
#define tcg_op_insert_after tcg_op_insert_after_ppc64
#define tcg_cpu_exec_time tcg_cpu_exec_time_ppc64
#define tcg_gen_code tcg_gen_code_ppc64
#define tcg_gen_op1 tcg_gen_op1_ppc64
#define tcg_gen_op2 tcg_gen_op2_ppc64
#define tcg_gen_op3 tcg_gen_op3_ppc64
#define tcg_gen_op4 tcg_gen_op4_ppc64
#define tcg_gen_op5 tcg_gen_op5_ppc64
#define tcg_gen_op6 tcg_gen_op6_ppc64
#define tcg_gen_mb tcg_gen_mb_ppc64
#define tcg_gen_addi_i32 tcg_gen_addi_i32_ppc64
#define tcg_gen_subfi_i32 tcg_gen_subfi_i32_ppc64
#define tcg_gen_subi_i32 tcg_gen_subi_i32_ppc64
#define tcg_gen_andi_i32 tcg_gen_andi_i32_ppc64
#define tcg_gen_ori_i32 tcg_gen_ori_i32_ppc64
#define tcg_gen_xori_i32 tcg_gen_xori_i32_ppc64
#define tcg_gen_shli_i32 tcg_gen_shli_i32_ppc64
#define tcg_gen_shri_i32 tcg_gen_shri_i32_ppc64
#define tcg_gen_sari_i32 tcg_gen_sari_i32_ppc64
#define tcg_gen_brcond_i32 tcg_gen_brcond_i32_ppc64
#define tcg_gen_brcondi_i32 tcg_gen_brcondi_i32_ppc64
#define tcg_gen_setcond_i32 tcg_gen_setcond_i32_ppc64
#define tcg_gen_setcondi_i32 tcg_gen_setcondi_i32_ppc64
#define tcg_gen_muli_i32 tcg_gen_muli_i32_ppc64
#define tcg_gen_div_i32 tcg_gen_div_i32_ppc64
#define tcg_gen_rem_i32 tcg_gen_rem_i32_ppc64
#define tcg_gen_divu_i32 tcg_gen_divu_i32_ppc64
#define tcg_gen_remu_i32 tcg_gen_remu_i32_ppc64
#define tcg_gen_andc_i32 tcg_gen_andc_i32_ppc64
#define tcg_gen_eqv_i32 tcg_gen_eqv_i32_ppc64
#define tcg_gen_nand_i32 tcg_gen_nand_i32_ppc64
#define tcg_gen_nor_i32 tcg_gen_nor_i32_ppc64
#define tcg_gen_orc_i32 tcg_gen_orc_i32_ppc64
#define tcg_gen_clz_i32 tcg_gen_clz_i32_ppc64
#define tcg_gen_clzi_i32 tcg_gen_clzi_i32_ppc64
#define tcg_gen_ctz_i32 tcg_gen_ctz_i32_ppc64
#define tcg_gen_ctzi_i32 tcg_gen_ctzi_i32_ppc64
#define tcg_gen_clrsb_i32 tcg_gen_clrsb_i32_ppc64
#define tcg_gen_ctpop_i32 tcg_gen_ctpop_i32_ppc64
#define tcg_gen_rotl_i32 tcg_gen_rotl_i32_ppc64
#define tcg_gen_rotli_i32 tcg_gen_rotli_i32_ppc64
#define tcg_gen_rotr_i32 tcg_gen_rotr_i32_ppc64
#define tcg_gen_rotri_i32 tcg_gen_rotri_i32_ppc64
#define tcg_gen_deposit_i32 tcg_gen_deposit_i32_ppc64
#define tcg_gen_deposit_z_i32 tcg_gen_deposit_z_i32_ppc64
#define tcg_gen_extract_i32 tcg_gen_extract_i32_ppc64
#define tcg_gen_sextract_i32 tcg_gen_sextract_i32_ppc64
#define tcg_gen_extract2_i32 tcg_gen_extract2_i32_ppc64
#define tcg_gen_movcond_i32 tcg_gen_movcond_i32_ppc64
#define tcg_gen_add2_i32 tcg_gen_add2_i32_ppc64
#define tcg_gen_sub2_i32 tcg_gen_sub2_i32_ppc64
#define tcg_gen_mulu2_i32 tcg_gen_mulu2_i32_ppc64
#define tcg_gen_muls2_i32 tcg_gen_muls2_i32_ppc64
#define tcg_gen_mulsu2_i32 tcg_gen_mulsu2_i32_ppc64
#define tcg_gen_ext8s_i32 tcg_gen_ext8s_i32_ppc64
#define tcg_gen_ext16s_i32 tcg_gen_ext16s_i32_ppc64
#define tcg_gen_ext8u_i32 tcg_gen_ext8u_i32_ppc64
#define tcg_gen_ext16u_i32 tcg_gen_ext16u_i32_ppc64
#define tcg_gen_bswap16_i32 tcg_gen_bswap16_i32_ppc64
#define tcg_gen_bswap32_i32 tcg_gen_bswap32_i32_ppc64
#define tcg_gen_smin_i32 tcg_gen_smin_i32_ppc64
#define tcg_gen_umin_i32 tcg_gen_umin_i32_ppc64
#define tcg_gen_smax_i32 tcg_gen_smax_i32_ppc64
#define tcg_gen_umax_i32 tcg_gen_umax_i32_ppc64
#define tcg_gen_abs_i32 tcg_gen_abs_i32_ppc64
#define tcg_gen_addi_i64 tcg_gen_addi_i64_ppc64
#define tcg_gen_subfi_i64 tcg_gen_subfi_i64_ppc64
#define tcg_gen_subi_i64 tcg_gen_subi_i64_ppc64
#define tcg_gen_andi_i64 tcg_gen_andi_i64_ppc64
#define tcg_gen_ori_i64 tcg_gen_ori_i64_ppc64
#define tcg_gen_xori_i64 tcg_gen_xori_i64_ppc64
#define tcg_gen_shli_i64 tcg_gen_shli_i64_ppc64
#define tcg_gen_shri_i64 tcg_gen_shri_i64_ppc64
#define tcg_gen_sari_i64 tcg_gen_sari_i64_ppc64
#define tcg_gen_brcond_i64 tcg_gen_brcond_i64_ppc64
#define tcg_gen_brcondi_i64 tcg_gen_brcondi_i64_ppc64
#define tcg_gen_setcond_i64 tcg_gen_setcond_i64_ppc64
#define tcg_gen_setcondi_i64 tcg_gen_setcondi_i64_ppc64
#define tcg_gen_muli_i64 tcg_gen_muli_i64_ppc64
#define tcg_gen_div_i64 tcg_gen_div_i64_ppc64
#define tcg_gen_rem_i64 tcg_gen_rem_i64_ppc64
#define tcg_gen_divu_i64 tcg_gen_divu_i64_ppc64
#define tcg_gen_remu_i64 tcg_gen_remu_i64_ppc64
#define tcg_gen_ext8s_i64 tcg_gen_ext8s_i64_ppc64
#define tcg_gen_ext16s_i64 tcg_gen_ext16s_i64_ppc64
#define tcg_gen_ext32s_i64 tcg_gen_ext32s_i64_ppc64
#define tcg_gen_ext8u_i64 tcg_gen_ext8u_i64_ppc64
#define tcg_gen_ext16u_i64 tcg_gen_ext16u_i64_ppc64
#define tcg_gen_ext32u_i64 tcg_gen_ext32u_i64_ppc64
#define tcg_gen_bswap16_i64 tcg_gen_bswap16_i64_ppc64
#define tcg_gen_bswap32_i64 tcg_gen_bswap32_i64_ppc64
#define tcg_gen_bswap64_i64 tcg_gen_bswap64_i64_ppc64
#define tcg_gen_not_i64 tcg_gen_not_i64_ppc64
#define tcg_gen_andc_i64 tcg_gen_andc_i64_ppc64
#define tcg_gen_eqv_i64 tcg_gen_eqv_i64_ppc64
#define tcg_gen_nand_i64 tcg_gen_nand_i64_ppc64
#define tcg_gen_nor_i64 tcg_gen_nor_i64_ppc64
#define tcg_gen_orc_i64 tcg_gen_orc_i64_ppc64
#define tcg_gen_clz_i64 tcg_gen_clz_i64_ppc64
#define tcg_gen_clzi_i64 tcg_gen_clzi_i64_ppc64
#define tcg_gen_ctz_i64 tcg_gen_ctz_i64_ppc64
#define tcg_gen_ctzi_i64 tcg_gen_ctzi_i64_ppc64
#define tcg_gen_clrsb_i64 tcg_gen_clrsb_i64_ppc64
#define tcg_gen_ctpop_i64 tcg_gen_ctpop_i64_ppc64
#define tcg_gen_rotl_i64 tcg_gen_rotl_i64_ppc64
#define tcg_gen_rotli_i64 tcg_gen_rotli_i64_ppc64
#define tcg_gen_rotr_i64 tcg_gen_rotr_i64_ppc64
#define tcg_gen_rotri_i64 tcg_gen_rotri_i64_ppc64
#define tcg_gen_deposit_i64 tcg_gen_deposit_i64_ppc64
#define tcg_gen_deposit_z_i64 tcg_gen_deposit_z_i64_ppc64
#define tcg_gen_extract_i64 tcg_gen_extract_i64_ppc64
#define tcg_gen_sextract_i64 tcg_gen_sextract_i64_ppc64
#define tcg_gen_extract2_i64 tcg_gen_extract2_i64_ppc64
#define tcg_gen_movcond_i64 tcg_gen_movcond_i64_ppc64
#define tcg_gen_add2_i64 tcg_gen_add2_i64_ppc64
#define tcg_gen_sub2_i64 tcg_gen_sub2_i64_ppc64
#define tcg_gen_mulu2_i64 tcg_gen_mulu2_i64_ppc64
#define tcg_gen_muls2_i64 tcg_gen_muls2_i64_ppc64
#define tcg_gen_mulsu2_i64 tcg_gen_mulsu2_i64_ppc64
#define tcg_gen_smin_i64 tcg_gen_smin_i64_ppc64
#define tcg_gen_umin_i64 tcg_gen_umin_i64_ppc64
#define tcg_gen_smax_i64 tcg_gen_smax_i64_ppc64
#define tcg_gen_umax_i64 tcg_gen_umax_i64_ppc64
#define tcg_gen_abs_i64 tcg_gen_abs_i64_ppc64
#define tcg_gen_extrl_i64_i32 tcg_gen_extrl_i64_i32_ppc64
#define tcg_gen_extrh_i64_i32 tcg_gen_extrh_i64_i32_ppc64
#define tcg_gen_extu_i32_i64 tcg_gen_extu_i32_i64_ppc64
#define tcg_gen_ext_i32_i64 tcg_gen_ext_i32_i64_ppc64
#define tcg_gen_concat_i32_i64 tcg_gen_concat_i32_i64_ppc64
#define tcg_gen_extr_i64_i32 tcg_gen_extr_i64_i32_ppc64
#define tcg_gen_extr32_i64 tcg_gen_extr32_i64_ppc64
#define tcg_gen_exit_tb tcg_gen_exit_tb_ppc64
#define tcg_gen_goto_tb tcg_gen_goto_tb_ppc64
#define tcg_gen_lookup_and_goto_ptr tcg_gen_lookup_and_goto_ptr_ppc64
#define check_exit_request check_exit_request_ppc64
#define tcg_gen_qemu_ld_i32 tcg_gen_qemu_ld_i32_ppc64
#define tcg_gen_qemu_st_i32 tcg_gen_qemu_st_i32_ppc64
#define tcg_gen_qemu_ld_i64 tcg_gen_qemu_ld_i64_ppc64
#define tcg_gen_qemu_st_i64 tcg_gen_qemu_st_i64_ppc64
#define tcg_gen_atomic_cmpxchg_i32 tcg_gen_atomic_cmpxchg_i32_ppc64
#define tcg_gen_atomic_cmpxchg_i64 tcg_gen_atomic_cmpxchg_i64_ppc64
#define tcg_gen_atomic_fetch_add_i32 tcg_gen_atomic_fetch_add_i32_ppc64
#define tcg_gen_atomic_fetch_add_i64 tcg_gen_atomic_fetch_add_i64_ppc64
#define tcg_gen_atomic_fetch_and_i32 tcg_gen_atomic_fetch_and_i32_ppc64
#define tcg_gen_atomic_fetch_and_i64 tcg_gen_atomic_fetch_and_i64_ppc64
#define tcg_gen_atomic_fetch_or_i32 tcg_gen_atomic_fetch_or_i32_ppc64
#define tcg_gen_atomic_fetch_or_i64 tcg_gen_atomic_fetch_or_i64_ppc64
#define tcg_gen_atomic_fetch_xor_i32 tcg_gen_atomic_fetch_xor_i32_ppc64
#define tcg_gen_atomic_fetch_xor_i64 tcg_gen_atomic_fetch_xor_i64_ppc64
#define tcg_gen_atomic_fetch_smin_i32 tcg_gen_atomic_fetch_smin_i32_ppc64
#define tcg_gen_atomic_fetch_smin_i64 tcg_gen_atomic_fetch_smin_i64_ppc64
#define tcg_gen_atomic_fetch_umin_i32 tcg_gen_atomic_fetch_umin_i32_ppc64
#define tcg_gen_atomic_fetch_umin_i64 tcg_gen_atomic_fetch_umin_i64_ppc64
#define tcg_gen_atomic_fetch_smax_i32 tcg_gen_atomic_fetch_smax_i32_ppc64
#define tcg_gen_atomic_fetch_smax_i64 tcg_gen_atomic_fetch_smax_i64_ppc64
#define tcg_gen_atomic_fetch_umax_i32 tcg_gen_atomic_fetch_umax_i32_ppc64
#define tcg_gen_atomic_fetch_umax_i64 tcg_gen_atomic_fetch_umax_i64_ppc64
#define tcg_gen_atomic_add_fetch_i32 tcg_gen_atomic_add_fetch_i32_ppc64
#define tcg_gen_atomic_add_fetch_i64 tcg_gen_atomic_add_fetch_i64_ppc64
#define tcg_gen_atomic_and_fetch_i32 tcg_gen_atomic_and_fetch_i32_ppc64
#define tcg_gen_atomic_and_fetch_i64 tcg_gen_atomic_and_fetch_i64_ppc64
#define tcg_gen_atomic_or_fetch_i32 tcg_gen_atomic_or_fetch_i32_ppc64
#define tcg_gen_atomic_or_fetch_i64 tcg_gen_atomic_or_fetch_i64_ppc64
#define tcg_gen_atomic_xor_fetch_i32 tcg_gen_atomic_xor_fetch_i32_ppc64
#define tcg_gen_atomic_xor_fetch_i64 tcg_gen_atomic_xor_fetch_i64_ppc64
#define tcg_gen_atomic_smin_fetch_i32 tcg_gen_atomic_smin_fetch_i32_ppc64
#define tcg_gen_atomic_smin_fetch_i64 tcg_gen_atomic_smin_fetch_i64_ppc64
#define tcg_gen_atomic_umin_fetch_i32 tcg_gen_atomic_umin_fetch_i32_ppc64
#define tcg_gen_atomic_umin_fetch_i64 tcg_gen_atomic_umin_fetch_i64_ppc64
#define tcg_gen_atomic_smax_fetch_i32 tcg_gen_atomic_smax_fetch_i32_ppc64
#define tcg_gen_atomic_smax_fetch_i64 tcg_gen_atomic_smax_fetch_i64_ppc64
#define tcg_gen_atomic_umax_fetch_i32 tcg_gen_atomic_umax_fetch_i32_ppc64
#define tcg_gen_atomic_umax_fetch_i64 tcg_gen_atomic_umax_fetch_i64_ppc64
#define tcg_gen_atomic_xchg_i32 tcg_gen_atomic_xchg_i32_ppc64
#define tcg_gen_atomic_xchg_i64 tcg_gen_atomic_xchg_i64_ppc64
#define simd_desc simd_desc_ppc64
#define tcg_gen_gvec_2_ool tcg_gen_gvec_2_ool_ppc64
#define tcg_gen_gvec_2i_ool tcg_gen_gvec_2i_ool_ppc64
#define tcg_gen_gvec_3_ool tcg_gen_gvec_3_ool_ppc64
#define tcg_gen_gvec_4_ool tcg_gen_gvec_4_ool_ppc64
#define tcg_gen_gvec_5_ool tcg_gen_gvec_5_ool_ppc64
#define tcg_gen_gvec_2_ptr tcg_gen_gvec_2_ptr_ppc64
#define tcg_gen_gvec_3_ptr tcg_gen_gvec_3_ptr_ppc64
#define tcg_gen_gvec_4_ptr tcg_gen_gvec_4_ptr_ppc64
#define tcg_gen_gvec_5_ptr tcg_gen_gvec_5_ptr_ppc64
#define tcg_gen_gvec_2 tcg_gen_gvec_2_ppc64
#define tcg_gen_gvec_2i tcg_gen_gvec_2i_ppc64
#define tcg_gen_gvec_2s tcg_gen_gvec_2s_ppc64
#define tcg_gen_gvec_3 tcg_gen_gvec_3_ppc64
#define tcg_gen_gvec_3i tcg_gen_gvec_3i_ppc64
#define tcg_gen_gvec_4 tcg_gen_gvec_4_ppc64
#define tcg_gen_gvec_mov tcg_gen_gvec_mov_ppc64
#define tcg_gen_gvec_dup_i32 tcg_gen_gvec_dup_i32_ppc64
#define tcg_gen_gvec_dup_i64 tcg_gen_gvec_dup_i64_ppc64
#define tcg_gen_gvec_dup_mem tcg_gen_gvec_dup_mem_ppc64
#define tcg_gen_gvec_dup64i tcg_gen_gvec_dup64i_ppc64
#define tcg_gen_gvec_dup32i tcg_gen_gvec_dup32i_ppc64
#define tcg_gen_gvec_dup16i tcg_gen_gvec_dup16i_ppc64
#define tcg_gen_gvec_dup8i tcg_gen_gvec_dup8i_ppc64
#define tcg_gen_gvec_not tcg_gen_gvec_not_ppc64
#define tcg_gen_vec_add8_i64 tcg_gen_vec_add8_i64_ppc64
#define tcg_gen_vec_add16_i64 tcg_gen_vec_add16_i64_ppc64
#define tcg_gen_vec_add32_i64 tcg_gen_vec_add32_i64_ppc64
#define tcg_gen_gvec_add tcg_gen_gvec_add_ppc64
#define tcg_gen_gvec_adds tcg_gen_gvec_adds_ppc64
#define tcg_gen_gvec_addi tcg_gen_gvec_addi_ppc64
#define tcg_gen_gvec_subs tcg_gen_gvec_subs_ppc64
#define tcg_gen_vec_sub8_i64 tcg_gen_vec_sub8_i64_ppc64
#define tcg_gen_vec_sub16_i64 tcg_gen_vec_sub16_i64_ppc64
#define tcg_gen_vec_sub32_i64 tcg_gen_vec_sub32_i64_ppc64
#define tcg_gen_gvec_sub tcg_gen_gvec_sub_ppc64
#define tcg_gen_gvec_mul tcg_gen_gvec_mul_ppc64
#define tcg_gen_gvec_muls tcg_gen_gvec_muls_ppc64
#define tcg_gen_gvec_muli tcg_gen_gvec_muli_ppc64
#define tcg_gen_gvec_ssadd tcg_gen_gvec_ssadd_ppc64
#define tcg_gen_gvec_sssub tcg_gen_gvec_sssub_ppc64
#define tcg_gen_gvec_usadd tcg_gen_gvec_usadd_ppc64
#define tcg_gen_gvec_ussub tcg_gen_gvec_ussub_ppc64
#define tcg_gen_gvec_smin tcg_gen_gvec_smin_ppc64
#define tcg_gen_gvec_umin tcg_gen_gvec_umin_ppc64
#define tcg_gen_gvec_smax tcg_gen_gvec_smax_ppc64
#define tcg_gen_gvec_umax tcg_gen_gvec_umax_ppc64
#define tcg_gen_vec_neg8_i64 tcg_gen_vec_neg8_i64_ppc64
#define tcg_gen_vec_neg16_i64 tcg_gen_vec_neg16_i64_ppc64
#define tcg_gen_vec_neg32_i64 tcg_gen_vec_neg32_i64_ppc64
#define tcg_gen_gvec_neg tcg_gen_gvec_neg_ppc64
#define tcg_gen_gvec_abs tcg_gen_gvec_abs_ppc64
#define tcg_gen_gvec_and tcg_gen_gvec_and_ppc64
#define tcg_gen_gvec_or tcg_gen_gvec_or_ppc64
#define tcg_gen_gvec_xor tcg_gen_gvec_xor_ppc64
#define tcg_gen_gvec_andc tcg_gen_gvec_andc_ppc64
#define tcg_gen_gvec_orc tcg_gen_gvec_orc_ppc64
#define tcg_gen_gvec_nand tcg_gen_gvec_nand_ppc64
#define tcg_gen_gvec_nor tcg_gen_gvec_nor_ppc64
#define tcg_gen_gvec_eqv tcg_gen_gvec_eqv_ppc64
#define tcg_gen_gvec_ands tcg_gen_gvec_ands_ppc64
#define tcg_gen_gvec_andi tcg_gen_gvec_andi_ppc64
#define tcg_gen_gvec_xors tcg_gen_gvec_xors_ppc64
#define tcg_gen_gvec_xori tcg_gen_gvec_xori_ppc64
#define tcg_gen_gvec_ors tcg_gen_gvec_ors_ppc64
#define tcg_gen_gvec_ori tcg_gen_gvec_ori_ppc64
#define tcg_gen_vec_shl8i_i64 tcg_gen_vec_shl8i_i64_ppc64
#define tcg_gen_vec_shl16i_i64 tcg_gen_vec_shl16i_i64_ppc64
#define tcg_gen_gvec_shli tcg_gen_gvec_shli_ppc64
#define tcg_gen_vec_shr8i_i64 tcg_gen_vec_shr8i_i64_ppc64
#define tcg_gen_vec_shr16i_i64 tcg_gen_vec_shr16i_i64_ppc64
#define tcg_gen_gvec_shri tcg_gen_gvec_shri_ppc64
#define tcg_gen_vec_sar8i_i64 tcg_gen_vec_sar8i_i64_ppc64
#define tcg_gen_vec_sar16i_i64 tcg_gen_vec_sar16i_i64_ppc64
#define tcg_gen_gvec_sari tcg_gen_gvec_sari_ppc64
#define tcg_gen_gvec_shls tcg_gen_gvec_shls_ppc64
#define tcg_gen_gvec_shrs tcg_gen_gvec_shrs_ppc64
#define tcg_gen_gvec_sars tcg_gen_gvec_sars_ppc64
#define tcg_gen_gvec_shlv tcg_gen_gvec_shlv_ppc64
#define tcg_gen_gvec_shrv tcg_gen_gvec_shrv_ppc64
#define tcg_gen_gvec_sarv tcg_gen_gvec_sarv_ppc64
#define tcg_gen_gvec_cmp tcg_gen_gvec_cmp_ppc64
#define tcg_gen_gvec_bitsel tcg_gen_gvec_bitsel_ppc64
#define tcg_can_emit_vecop_list tcg_can_emit_vecop_list_ppc64
#define vec_gen_2 vec_gen_2_ppc64
#define vec_gen_3 vec_gen_3_ppc64
#define vec_gen_4 vec_gen_4_ppc64
#define tcg_gen_mov_vec tcg_gen_mov_vec_ppc64
#define tcg_const_zeros_vec tcg_const_zeros_vec_ppc64
#define tcg_const_ones_vec tcg_const_ones_vec_ppc64
#define tcg_const_zeros_vec_matching tcg_const_zeros_vec_matching_ppc64
#define tcg_const_ones_vec_matching tcg_const_ones_vec_matching_ppc64
#define tcg_gen_dup64i_vec tcg_gen_dup64i_vec_ppc64
#define tcg_gen_dup32i_vec tcg_gen_dup32i_vec_ppc64
#define tcg_gen_dup16i_vec tcg_gen_dup16i_vec_ppc64
#define tcg_gen_dup8i_vec tcg_gen_dup8i_vec_ppc64
#define tcg_gen_dupi_vec tcg_gen_dupi_vec_ppc64
#define tcg_gen_dup_i64_vec tcg_gen_dup_i64_vec_ppc64
#define tcg_gen_dup_i32_vec tcg_gen_dup_i32_vec_ppc64
#define tcg_gen_dup_mem_vec tcg_gen_dup_mem_vec_ppc64
#define tcg_gen_ld_vec tcg_gen_ld_vec_ppc64
#define tcg_gen_st_vec tcg_gen_st_vec_ppc64
#define tcg_gen_stl_vec tcg_gen_stl_vec_ppc64
#define tcg_gen_and_vec tcg_gen_and_vec_ppc64
#define tcg_gen_or_vec tcg_gen_or_vec_ppc64
#define tcg_gen_xor_vec tcg_gen_xor_vec_ppc64
#define tcg_gen_andc_vec tcg_gen_andc_vec_ppc64
#define tcg_gen_orc_vec tcg_gen_orc_vec_ppc64
#define tcg_gen_nand_vec tcg_gen_nand_vec_ppc64
#define tcg_gen_nor_vec tcg_gen_nor_vec_ppc64
#define tcg_gen_eqv_vec tcg_gen_eqv_vec_ppc64
#define tcg_gen_not_vec tcg_gen_not_vec_ppc64
#define tcg_gen_neg_vec tcg_gen_neg_vec_ppc64
#define tcg_gen_abs_vec tcg_gen_abs_vec_ppc64
#define tcg_gen_shli_vec tcg_gen_shli_vec_ppc64
#define tcg_gen_shri_vec tcg_gen_shri_vec_ppc64
#define tcg_gen_sari_vec tcg_gen_sari_vec_ppc64
#define tcg_gen_cmp_vec tcg_gen_cmp_vec_ppc64
#define tcg_gen_add_vec tcg_gen_add_vec_ppc64
#define tcg_gen_sub_vec tcg_gen_sub_vec_ppc64
#define tcg_gen_mul_vec tcg_gen_mul_vec_ppc64
#define tcg_gen_ssadd_vec tcg_gen_ssadd_vec_ppc64
#define tcg_gen_usadd_vec tcg_gen_usadd_vec_ppc64
#define tcg_gen_sssub_vec tcg_gen_sssub_vec_ppc64
#define tcg_gen_ussub_vec tcg_gen_ussub_vec_ppc64
#define tcg_gen_smin_vec tcg_gen_smin_vec_ppc64
#define tcg_gen_umin_vec tcg_gen_umin_vec_ppc64
#define tcg_gen_smax_vec tcg_gen_smax_vec_ppc64
#define tcg_gen_umax_vec tcg_gen_umax_vec_ppc64
#define tcg_gen_shlv_vec tcg_gen_shlv_vec_ppc64
#define tcg_gen_shrv_vec tcg_gen_shrv_vec_ppc64
#define tcg_gen_sarv_vec tcg_gen_sarv_vec_ppc64
#define tcg_gen_shls_vec tcg_gen_shls_vec_ppc64
#define tcg_gen_shrs_vec tcg_gen_shrs_vec_ppc64
#define tcg_gen_sars_vec tcg_gen_sars_vec_ppc64
#define tcg_gen_bitsel_vec tcg_gen_bitsel_vec_ppc64
#define tcg_gen_cmpsel_vec tcg_gen_cmpsel_vec_ppc64
#define tb_htable_lookup tb_htable_lookup_ppc64
#define tb_set_jmp_target tb_set_jmp_target_ppc64
#define cpu_exec cpu_exec_ppc64
#define cpu_loop_exit_noexc cpu_loop_exit_noexc_ppc64
#define cpu_reloading_memory_map cpu_reloading_memory_map_ppc64
#define cpu_loop_exit cpu_loop_exit_ppc64
#define cpu_loop_exit_restore cpu_loop_exit_restore_ppc64
#define cpu_loop_exit_atomic cpu_loop_exit_atomic_ppc64
#define tlb_init tlb_init_ppc64
#define tlb_flush_by_mmuidx tlb_flush_by_mmuidx_ppc64
#define tlb_flush tlb_flush_ppc64
#define tlb_flush_by_mmuidx_all_cpus tlb_flush_by_mmuidx_all_cpus_ppc64
#define tlb_flush_all_cpus tlb_flush_all_cpus_ppc64
#define tlb_flush_by_mmuidx_all_cpus_synced tlb_flush_by_mmuidx_all_cpus_synced_ppc64
#define tlb_flush_all_cpus_synced tlb_flush_all_cpus_synced_ppc64
#define tlb_flush_page_by_mmuidx tlb_flush_page_by_mmuidx_ppc64
#define tlb_flush_page tlb_flush_page_ppc64
#define tlb_flush_page_by_mmuidx_all_cpus tlb_flush_page_by_mmuidx_all_cpus_ppc64
#define tlb_flush_page_all_cpus tlb_flush_page_all_cpus_ppc64
#define tlb_flush_page_by_mmuidx_all_cpus_synced tlb_flush_page_by_mmuidx_all_cpus_synced_ppc64
#define tlb_flush_page_all_cpus_synced tlb_flush_page_all_cpus_synced_ppc64
#define tlb_protect_code tlb_protect_code_ppc64
#define tlb_unprotect_code tlb_unprotect_code_ppc64
#define tlb_reset_dirty tlb_reset_dirty_ppc64
#define tlb_set_dirty tlb_set_dirty_ppc64
#define tlb_set_page_with_attrs tlb_set_page_with_attrs_ppc64
#define tlb_set_page tlb_set_page_ppc64
#define get_page_addr_code_hostp get_page_addr_code_hostp_ppc64
#define get_page_addr_code get_page_addr_code_ppc64
#define probe_access probe_access_ppc64
#define tlb_vaddr_to_host tlb_vaddr_to_host_ppc64
#define tlb_vaddr_to_paddr tlb_vaddr_to_paddr_ppc64
#define helper_ret_ldub_mmu helper_ret_ldub_mmu_ppc64
#define helper_le_lduw_mmu helper_le_lduw_mmu_ppc64
#define helper_be_lduw_mmu helper_be_lduw_mmu_ppc64
#define helper_le_ldul_mmu helper_le_ldul_mmu_ppc64
#define helper_be_ldul_mmu helper_be_ldul_mmu_ppc64
#define helper_le_ldq_mmu helper_le_ldq_mmu_ppc64
#define helper_be_ldq_mmu helper_be_ldq_mmu_ppc64
#define helper_ret_ldsb_mmu helper_ret_ldsb_mmu_ppc64
#define helper_le_ldsw_mmu helper_le_ldsw_mmu_ppc64
#define helper_be_ldsw_mmu helper_be_ldsw_mmu_ppc64
#define helper_le_ldsl_mmu helper_le_ldsl_mmu_ppc64
#define helper_be_ldsl_mmu helper_be_ldsl_mmu_ppc64
#define cpu_ldub_mmuidx_ra cpu_ldub_mmuidx_ra_ppc64
#define cpu_ldsb_mmuidx_ra cpu_ldsb_mmuidx_ra_ppc64
#define cpu_lduw_mmuidx_ra cpu_lduw_mmuidx_ra_ppc64
#define cpu_ldsw_mmuidx_ra cpu_ldsw_mmuidx_ra_ppc64
#define cpu_ldl_mmuidx_ra cpu_ldl_mmuidx_ra_ppc64
#define cpu_ldq_mmuidx_ra cpu_ldq_mmuidx_ra_ppc64
#define cpu_ldub_data_ra cpu_ldub_data_ra_ppc64
#define cpu_ldsb_data_ra cpu_ldsb_data_ra_ppc64
#define cpu_lduw_data_ra cpu_lduw_data_ra_ppc64
#define cpu_ldsw_data_ra cpu_ldsw_data_ra_ppc64
#define cpu_ldl_data_ra cpu_ldl_data_ra_ppc64
#define cpu_ldq_data_ra cpu_ldq_data_ra_ppc64
#define cpu_ldub_data cpu_ldub_data_ppc64
#define cpu_ldsb_data cpu_ldsb_data_ppc64
#define cpu_lduw_data cpu_lduw_data_ppc64
#define cpu_ldsw_data cpu_ldsw_data_ppc64
#define cpu_ldl_data cpu_ldl_data_ppc64
#define cpu_ldq_data cpu_ldq_data_ppc64
#define helper_ret_stb_mmu helper_ret_stb_mmu_ppc64
#define helper_le_stw_mmu helper_le_stw_mmu_ppc64
#define helper_be_stw_mmu helper_be_stw_mmu_ppc64
#define helper_le_stl_mmu helper_le_stl_mmu_ppc64
#define helper_be_stl_mmu helper_be_stl_mmu_ppc64
#define helper_le_stq_mmu helper_le_stq_mmu_ppc64
#define helper_be_stq_mmu helper_be_stq_mmu_ppc64
#define cpu_stb_mmuidx_ra cpu_stb_mmuidx_ra_ppc64
#define cpu_stw_mmuidx_ra cpu_stw_mmuidx_ra_ppc64
#define cpu_stl_mmuidx_ra cpu_stl_mmuidx_ra_ppc64
#define cpu_stq_mmuidx_ra cpu_stq_mmuidx_ra_ppc64
#define cpu_stb_data_ra cpu_stb_data_ra_ppc64
#define cpu_stw_data_ra cpu_stw_data_ra_ppc64
#define cpu_stl_data_ra cpu_stl_data_ra_ppc64
#define cpu_stq_data_ra cpu_stq_data_ra_ppc64
#define cpu_stb_data cpu_stb_data_ppc64
#define cpu_stw_data cpu_stw_data_ppc64
#define cpu_stl_data cpu_stl_data_ppc64
#define cpu_stq_data cpu_stq_data_ppc64
#define helper_atomic_cmpxchgb_mmu helper_atomic_cmpxchgb_mmu_ppc64
#define helper_atomic_xchgb_mmu helper_atomic_xchgb_mmu_ppc64
#define helper_atomic_fetch_addb_mmu helper_atomic_fetch_addb_mmu_ppc64
#define helper_atomic_fetch_andb_mmu helper_atomic_fetch_andb_mmu_ppc64
#define helper_atomic_fetch_orb_mmu helper_atomic_fetch_orb_mmu_ppc64
#define helper_atomic_fetch_xorb_mmu helper_atomic_fetch_xorb_mmu_ppc64
#define helper_atomic_add_fetchb_mmu helper_atomic_add_fetchb_mmu_ppc64
#define helper_atomic_and_fetchb_mmu helper_atomic_and_fetchb_mmu_ppc64
#define helper_atomic_or_fetchb_mmu helper_atomic_or_fetchb_mmu_ppc64
#define helper_atomic_xor_fetchb_mmu helper_atomic_xor_fetchb_mmu_ppc64
#define helper_atomic_fetch_sminb_mmu helper_atomic_fetch_sminb_mmu_ppc64
#define helper_atomic_fetch_uminb_mmu helper_atomic_fetch_uminb_mmu_ppc64
#define helper_atomic_fetch_smaxb_mmu helper_atomic_fetch_smaxb_mmu_ppc64
#define helper_atomic_fetch_umaxb_mmu helper_atomic_fetch_umaxb_mmu_ppc64
#define helper_atomic_smin_fetchb_mmu helper_atomic_smin_fetchb_mmu_ppc64
#define helper_atomic_umin_fetchb_mmu helper_atomic_umin_fetchb_mmu_ppc64
#define helper_atomic_smax_fetchb_mmu helper_atomic_smax_fetchb_mmu_ppc64
#define helper_atomic_umax_fetchb_mmu helper_atomic_umax_fetchb_mmu_ppc64
#define helper_atomic_cmpxchgw_le_mmu helper_atomic_cmpxchgw_le_mmu_ppc64
#define helper_atomic_xchgw_le_mmu helper_atomic_xchgw_le_mmu_ppc64
#define helper_atomic_fetch_addw_le_mmu helper_atomic_fetch_addw_le_mmu_ppc64
#define helper_atomic_fetch_andw_le_mmu helper_atomic_fetch_andw_le_mmu_ppc64
#define helper_atomic_fetch_orw_le_mmu helper_atomic_fetch_orw_le_mmu_ppc64
#define helper_atomic_fetch_xorw_le_mmu helper_atomic_fetch_xorw_le_mmu_ppc64
#define helper_atomic_add_fetchw_le_mmu helper_atomic_add_fetchw_le_mmu_ppc64
#define helper_atomic_and_fetchw_le_mmu helper_atomic_and_fetchw_le_mmu_ppc64
#define helper_atomic_or_fetchw_le_mmu helper_atomic_or_fetchw_le_mmu_ppc64
#define helper_atomic_xor_fetchw_le_mmu helper_atomic_xor_fetchw_le_mmu_ppc64
#define helper_atomic_fetch_sminw_le_mmu helper_atomic_fetch_sminw_le_mmu_ppc64
#define helper_atomic_fetch_uminw_le_mmu helper_atomic_fetch_uminw_le_mmu_ppc64
#define helper_atomic_fetch_smaxw_le_mmu helper_atomic_fetch_smaxw_le_mmu_ppc64
#define helper_atomic_fetch_umaxw_le_mmu helper_atomic_fetch_umaxw_le_mmu_ppc64
#define helper_atomic_smin_fetchw_le_mmu helper_atomic_smin_fetchw_le_mmu_ppc64
#define helper_atomic_umin_fetchw_le_mmu helper_atomic_umin_fetchw_le_mmu_ppc64
#define helper_atomic_smax_fetchw_le_mmu helper_atomic_smax_fetchw_le_mmu_ppc64
#define helper_atomic_umax_fetchw_le_mmu helper_atomic_umax_fetchw_le_mmu_ppc64
#define helper_atomic_cmpxchgw_be_mmu helper_atomic_cmpxchgw_be_mmu_ppc64
#define helper_atomic_xchgw_be_mmu helper_atomic_xchgw_be_mmu_ppc64
#define helper_atomic_fetch_andw_be_mmu helper_atomic_fetch_andw_be_mmu_ppc64
#define helper_atomic_fetch_orw_be_mmu helper_atomic_fetch_orw_be_mmu_ppc64
#define helper_atomic_fetch_xorw_be_mmu helper_atomic_fetch_xorw_be_mmu_ppc64
#define helper_atomic_and_fetchw_be_mmu helper_atomic_and_fetchw_be_mmu_ppc64
#define helper_atomic_or_fetchw_be_mmu helper_atomic_or_fetchw_be_mmu_ppc64
#define helper_atomic_xor_fetchw_be_mmu helper_atomic_xor_fetchw_be_mmu_ppc64
#define helper_atomic_fetch_sminw_be_mmu helper_atomic_fetch_sminw_be_mmu_ppc64
#define helper_atomic_fetch_uminw_be_mmu helper_atomic_fetch_uminw_be_mmu_ppc64
#define helper_atomic_fetch_smaxw_be_mmu helper_atomic_fetch_smaxw_be_mmu_ppc64
#define helper_atomic_fetch_umaxw_be_mmu helper_atomic_fetch_umaxw_be_mmu_ppc64
#define helper_atomic_smin_fetchw_be_mmu helper_atomic_smin_fetchw_be_mmu_ppc64
#define helper_atomic_umin_fetchw_be_mmu helper_atomic_umin_fetchw_be_mmu_ppc64
#define helper_atomic_smax_fetchw_be_mmu helper_atomic_smax_fetchw_be_mmu_ppc64
#define helper_atomic_umax_fetchw_be_mmu helper_atomic_umax_fetchw_be_mmu_ppc64
#define helper_atomic_fetch_addw_be_mmu helper_atomic_fetch_addw_be_mmu_ppc64
#define helper_atomic_add_fetchw_be_mmu helper_atomic_add_fetchw_be_mmu_ppc64
#define helper_atomic_cmpxchgl_le_mmu helper_atomic_cmpxchgl_le_mmu_ppc64
#define helper_atomic_xchgl_le_mmu helper_atomic_xchgl_le_mmu_ppc64
#define helper_atomic_fetch_addl_le_mmu helper_atomic_fetch_addl_le_mmu_ppc64
#define helper_atomic_fetch_andl_le_mmu helper_atomic_fetch_andl_le_mmu_ppc64
#define helper_atomic_fetch_orl_le_mmu helper_atomic_fetch_orl_le_mmu_ppc64
#define helper_atomic_fetch_xorl_le_mmu helper_atomic_fetch_xorl_le_mmu_ppc64
#define helper_atomic_add_fetchl_le_mmu helper_atomic_add_fetchl_le_mmu_ppc64
#define helper_atomic_and_fetchl_le_mmu helper_atomic_and_fetchl_le_mmu_ppc64
#define helper_atomic_or_fetchl_le_mmu helper_atomic_or_fetchl_le_mmu_ppc64
#define helper_atomic_xor_fetchl_le_mmu helper_atomic_xor_fetchl_le_mmu_ppc64
#define helper_atomic_fetch_sminl_le_mmu helper_atomic_fetch_sminl_le_mmu_ppc64
#define helper_atomic_fetch_uminl_le_mmu helper_atomic_fetch_uminl_le_mmu_ppc64
#define helper_atomic_fetch_smaxl_le_mmu helper_atomic_fetch_smaxl_le_mmu_ppc64
#define helper_atomic_fetch_umaxl_le_mmu helper_atomic_fetch_umaxl_le_mmu_ppc64
#define helper_atomic_smin_fetchl_le_mmu helper_atomic_smin_fetchl_le_mmu_ppc64
#define helper_atomic_umin_fetchl_le_mmu helper_atomic_umin_fetchl_le_mmu_ppc64
#define helper_atomic_smax_fetchl_le_mmu helper_atomic_smax_fetchl_le_mmu_ppc64
#define helper_atomic_umax_fetchl_le_mmu helper_atomic_umax_fetchl_le_mmu_ppc64
#define helper_atomic_cmpxchgl_be_mmu helper_atomic_cmpxchgl_be_mmu_ppc64
#define helper_atomic_xchgl_be_mmu helper_atomic_xchgl_be_mmu_ppc64
#define helper_atomic_fetch_andl_be_mmu helper_atomic_fetch_andl_be_mmu_ppc64
#define helper_atomic_fetch_orl_be_mmu helper_atomic_fetch_orl_be_mmu_ppc64
#define helper_atomic_fetch_xorl_be_mmu helper_atomic_fetch_xorl_be_mmu_ppc64
#define helper_atomic_and_fetchl_be_mmu helper_atomic_and_fetchl_be_mmu_ppc64
#define helper_atomic_or_fetchl_be_mmu helper_atomic_or_fetchl_be_mmu_ppc64
#define helper_atomic_xor_fetchl_be_mmu helper_atomic_xor_fetchl_be_mmu_ppc64
#define helper_atomic_fetch_sminl_be_mmu helper_atomic_fetch_sminl_be_mmu_ppc64
#define helper_atomic_fetch_uminl_be_mmu helper_atomic_fetch_uminl_be_mmu_ppc64
#define helper_atomic_fetch_smaxl_be_mmu helper_atomic_fetch_smaxl_be_mmu_ppc64
#define helper_atomic_fetch_umaxl_be_mmu helper_atomic_fetch_umaxl_be_mmu_ppc64
#define helper_atomic_smin_fetchl_be_mmu helper_atomic_smin_fetchl_be_mmu_ppc64
#define helper_atomic_umin_fetchl_be_mmu helper_atomic_umin_fetchl_be_mmu_ppc64
#define helper_atomic_smax_fetchl_be_mmu helper_atomic_smax_fetchl_be_mmu_ppc64
#define helper_atomic_umax_fetchl_be_mmu helper_atomic_umax_fetchl_be_mmu_ppc64
#define helper_atomic_fetch_addl_be_mmu helper_atomic_fetch_addl_be_mmu_ppc64
#define helper_atomic_add_fetchl_be_mmu helper_atomic_add_fetchl_be_mmu_ppc64
#define helper_atomic_cmpxchgq_le_mmu helper_atomic_cmpxchgq_le_mmu_ppc64
#define helper_atomic_xchgq_le_mmu helper_atomic_xchgq_le_mmu_ppc64
#define helper_atomic_fetch_addq_le_mmu helper_atomic_fetch_addq_le_mmu_ppc64
#define helper_atomic_fetch_andq_le_mmu helper_atomic_fetch_andq_le_mmu_ppc64
#define helper_atomic_fetch_orq_le_mmu helper_atomic_fetch_orq_le_mmu_ppc64
#define helper_atomic_fetch_xorq_le_mmu helper_atomic_fetch_xorq_le_mmu_ppc64
#define helper_atomic_add_fetchq_le_mmu helper_atomic_add_fetchq_le_mmu_ppc64
#define helper_atomic_and_fetchq_le_mmu helper_atomic_and_fetchq_le_mmu_ppc64
#define helper_atomic_or_fetchq_le_mmu helper_atomic_or_fetchq_le_mmu_ppc64
#define helper_atomic_xor_fetchq_le_mmu helper_atomic_xor_fetchq_le_mmu_ppc64
#define helper_atomic_fetch_sminq_le_mmu helper_atomic_fetch_sminq_le_mmu_ppc64
#define helper_atomic_fetch_uminq_le_mmu helper_atomic_fetch_uminq_le_mmu_ppc64
#define helper_atomic_fetch_smaxq_le_mmu helper_atomic_fetch_smaxq_le_mmu_ppc64
#define helper_atomic_fetch_umaxq_le_mmu helper_atomic_fetch_umaxq_le_mmu_ppc64
#define helper_atomic_smin_fetchq_le_mmu helper_atomic_smin_fetchq_le_mmu_ppc64
#define helper_atomic_umin_fetchq_le_mmu helper_atomic_umin_fetchq_le_mmu_ppc64
#define helper_atomic_smax_fetchq_le_mmu helper_atomic_smax_fetchq_le_mmu_ppc64
#define helper_atomic_umax_fetchq_le_mmu helper_atomic_umax_fetchq_le_mmu_ppc64
#define helper_atomic_cmpxchgq_be_mmu helper_atomic_cmpxchgq_be_mmu_ppc64
#define helper_atomic_xchgq_be_mmu helper_atomic_xchgq_be_mmu_ppc64
#define helper_atomic_fetch_andq_be_mmu helper_atomic_fetch_andq_be_mmu_ppc64
#define helper_atomic_fetch_orq_be_mmu helper_atomic_fetch_orq_be_mmu_ppc64
#define helper_atomic_fetch_xorq_be_mmu helper_atomic_fetch_xorq_be_mmu_ppc64
#define helper_atomic_and_fetchq_be_mmu helper_atomic_and_fetchq_be_mmu_ppc64
#define helper_atomic_or_fetchq_be_mmu helper_atomic_or_fetchq_be_mmu_ppc64
#define helper_atomic_xor_fetchq_be_mmu helper_atomic_xor_fetchq_be_mmu_ppc64
#define helper_atomic_fetch_sminq_be_mmu helper_atomic_fetch_sminq_be_mmu_ppc64
#define helper_atomic_fetch_uminq_be_mmu helper_atomic_fetch_uminq_be_mmu_ppc64
#define helper_atomic_fetch_smaxq_be_mmu helper_atomic_fetch_smaxq_be_mmu_ppc64
#define helper_atomic_fetch_umaxq_be_mmu helper_atomic_fetch_umaxq_be_mmu_ppc64
#define helper_atomic_smin_fetchq_be_mmu helper_atomic_smin_fetchq_be_mmu_ppc64
#define helper_atomic_umin_fetchq_be_mmu helper_atomic_umin_fetchq_be_mmu_ppc64
#define helper_atomic_smax_fetchq_be_mmu helper_atomic_smax_fetchq_be_mmu_ppc64
#define helper_atomic_umax_fetchq_be_mmu helper_atomic_umax_fetchq_be_mmu_ppc64
#define helper_atomic_fetch_addq_be_mmu helper_atomic_fetch_addq_be_mmu_ppc64
#define helper_atomic_add_fetchq_be_mmu helper_atomic_add_fetchq_be_mmu_ppc64
#define helper_atomic_cmpxchgb helper_atomic_cmpxchgb_ppc64
#define helper_atomic_xchgb helper_atomic_xchgb_ppc64
#define helper_atomic_fetch_addb helper_atomic_fetch_addb_ppc64
#define helper_atomic_fetch_andb helper_atomic_fetch_andb_ppc64
#define helper_atomic_fetch_orb helper_atomic_fetch_orb_ppc64
#define helper_atomic_fetch_xorb helper_atomic_fetch_xorb_ppc64
#define helper_atomic_add_fetchb helper_atomic_add_fetchb_ppc64
#define helper_atomic_and_fetchb helper_atomic_and_fetchb_ppc64
#define helper_atomic_or_fetchb helper_atomic_or_fetchb_ppc64
#define helper_atomic_xor_fetchb helper_atomic_xor_fetchb_ppc64
#define helper_atomic_fetch_sminb helper_atomic_fetch_sminb_ppc64
#define helper_atomic_fetch_uminb helper_atomic_fetch_uminb_ppc64
#define helper_atomic_fetch_smaxb helper_atomic_fetch_smaxb_ppc64
#define helper_atomic_fetch_umaxb helper_atomic_fetch_umaxb_ppc64
#define helper_atomic_smin_fetchb helper_atomic_smin_fetchb_ppc64
#define helper_atomic_umin_fetchb helper_atomic_umin_fetchb_ppc64
#define helper_atomic_smax_fetchb helper_atomic_smax_fetchb_ppc64
#define helper_atomic_umax_fetchb helper_atomic_umax_fetchb_ppc64
#define helper_atomic_cmpxchgw_le helper_atomic_cmpxchgw_le_ppc64
#define helper_atomic_xchgw_le helper_atomic_xchgw_le_ppc64
#define helper_atomic_fetch_addw_le helper_atomic_fetch_addw_le_ppc64
#define helper_atomic_fetch_andw_le helper_atomic_fetch_andw_le_ppc64
#define helper_atomic_fetch_orw_le helper_atomic_fetch_orw_le_ppc64
#define helper_atomic_fetch_xorw_le helper_atomic_fetch_xorw_le_ppc64
#define helper_atomic_add_fetchw_le helper_atomic_add_fetchw_le_ppc64
#define helper_atomic_and_fetchw_le helper_atomic_and_fetchw_le_ppc64
#define helper_atomic_or_fetchw_le helper_atomic_or_fetchw_le_ppc64
#define helper_atomic_xor_fetchw_le helper_atomic_xor_fetchw_le_ppc64
#define helper_atomic_fetch_sminw_le helper_atomic_fetch_sminw_le_ppc64
#define helper_atomic_fetch_uminw_le helper_atomic_fetch_uminw_le_ppc64
#define helper_atomic_fetch_smaxw_le helper_atomic_fetch_smaxw_le_ppc64
#define helper_atomic_fetch_umaxw_le helper_atomic_fetch_umaxw_le_ppc64
#define helper_atomic_smin_fetchw_le helper_atomic_smin_fetchw_le_ppc64
#define helper_atomic_umin_fetchw_le helper_atomic_umin_fetchw_le_ppc64
#define helper_atomic_smax_fetchw_le helper_atomic_smax_fetchw_le_ppc64
#define helper_atomic_umax_fetchw_le helper_atomic_umax_fetchw_le_ppc64
#define helper_atomic_cmpxchgw_be helper_atomic_cmpxchgw_be_ppc64
#define helper_atomic_xchgw_be helper_atomic_xchgw_be_ppc64
#define helper_atomic_fetch_andw_be helper_atomic_fetch_andw_be_ppc64
#define helper_atomic_fetch_orw_be helper_atomic_fetch_orw_be_ppc64
#define helper_atomic_fetch_xorw_be helper_atomic_fetch_xorw_be_ppc64
#define helper_atomic_and_fetchw_be helper_atomic_and_fetchw_be_ppc64
#define helper_atomic_or_fetchw_be helper_atomic_or_fetchw_be_ppc64
#define helper_atomic_xor_fetchw_be helper_atomic_xor_fetchw_be_ppc64
#define helper_atomic_fetch_sminw_be helper_atomic_fetch_sminw_be_ppc64
#define helper_atomic_fetch_uminw_be helper_atomic_fetch_uminw_be_ppc64
#define helper_atomic_fetch_smaxw_be helper_atomic_fetch_smaxw_be_ppc64
#define helper_atomic_fetch_umaxw_be helper_atomic_fetch_umaxw_be_ppc64
#define helper_atomic_smin_fetchw_be helper_atomic_smin_fetchw_be_ppc64
#define helper_atomic_umin_fetchw_be helper_atomic_umin_fetchw_be_ppc64
#define helper_atomic_smax_fetchw_be helper_atomic_smax_fetchw_be_ppc64
#define helper_atomic_umax_fetchw_be helper_atomic_umax_fetchw_be_ppc64
#define helper_atomic_fetch_addw_be helper_atomic_fetch_addw_be_ppc64
#define helper_atomic_add_fetchw_be helper_atomic_add_fetchw_be_ppc64
#define helper_atomic_cmpxchgl_le helper_atomic_cmpxchgl_le_ppc64
#define helper_atomic_xchgl_le helper_atomic_xchgl_le_ppc64
#define helper_atomic_fetch_addl_le helper_atomic_fetch_addl_le_ppc64
#define helper_atomic_fetch_andl_le helper_atomic_fetch_andl_le_ppc64
#define helper_atomic_fetch_orl_le helper_atomic_fetch_orl_le_ppc64
#define helper_atomic_fetch_xorl_le helper_atomic_fetch_xorl_le_ppc64
#define helper_atomic_add_fetchl_le helper_atomic_add_fetchl_le_ppc64
#define helper_atomic_and_fetchl_le helper_atomic_and_fetchl_le_ppc64
#define helper_atomic_or_fetchl_le helper_atomic_or_fetchl_le_ppc64
#define helper_atomic_xor_fetchl_le helper_atomic_xor_fetchl_le_ppc64
#define helper_atomic_fetch_sminl_le helper_atomic_fetch_sminl_le_ppc64
#define helper_atomic_fetch_uminl_le helper_atomic_fetch_uminl_le_ppc64
#define helper_atomic_fetch_smaxl_le helper_atomic_fetch_smaxl_le_ppc64
#define helper_atomic_fetch_umaxl_le helper_atomic_fetch_umaxl_le_ppc64
#define helper_atomic_smin_fetchl_le helper_atomic_smin_fetchl_le_ppc64
#define helper_atomic_umin_fetchl_le helper_atomic_umin_fetchl_le_ppc64
#define helper_atomic_smax_fetchl_le helper_atomic_smax_fetchl_le_ppc64
#define helper_atomic_umax_fetchl_le helper_atomic_umax_fetchl_le_ppc64
#define helper_atomic_cmpxchgl_be helper_atomic_cmpxchgl_be_ppc64
#define helper_atomic_xchgl_be helper_atomic_xchgl_be_ppc64
#define helper_atomic_fetch_andl_be helper_atomic_fetch_andl_be_ppc64
#define helper_atomic_fetch_orl_be helper_atomic_fetch_orl_be_ppc64
#define helper_atomic_fetch_xorl_be helper_atomic_fetch_xorl_be_ppc64
#define helper_atomic_and_fetchl_be helper_atomic_and_fetchl_be_ppc64
#define helper_atomic_or_fetchl_be helper_atomic_or_fetchl_be_ppc64
#define helper_atomic_xor_fetchl_be helper_atomic_xor_fetchl_be_ppc64
#define helper_atomic_fetch_sminl_be helper_atomic_fetch_sminl_be_ppc64
#define helper_atomic_fetch_uminl_be helper_atomic_fetch_uminl_be_ppc64
#define helper_atomic_fetch_smaxl_be helper_atomic_fetch_smaxl_be_ppc64
#define helper_atomic_fetch_umaxl_be helper_atomic_fetch_umaxl_be_ppc64
#define helper_atomic_smin_fetchl_be helper_atomic_smin_fetchl_be_ppc64
#define helper_atomic_umin_fetchl_be helper_atomic_umin_fetchl_be_ppc64
#define helper_atomic_smax_fetchl_be helper_atomic_smax_fetchl_be_ppc64
#define helper_atomic_umax_fetchl_be helper_atomic_umax_fetchl_be_ppc64
#define helper_atomic_fetch_addl_be helper_atomic_fetch_addl_be_ppc64
#define helper_atomic_add_fetchl_be helper_atomic_add_fetchl_be_ppc64
#define helper_atomic_cmpxchgq_le helper_atomic_cmpxchgq_le_ppc64
#define helper_atomic_xchgq_le helper_atomic_xchgq_le_ppc64
#define helper_atomic_fetch_addq_le helper_atomic_fetch_addq_le_ppc64
#define helper_atomic_fetch_andq_le helper_atomic_fetch_andq_le_ppc64
#define helper_atomic_fetch_orq_le helper_atomic_fetch_orq_le_ppc64
#define helper_atomic_fetch_xorq_le helper_atomic_fetch_xorq_le_ppc64
#define helper_atomic_add_fetchq_le helper_atomic_add_fetchq_le_ppc64
#define helper_atomic_and_fetchq_le helper_atomic_and_fetchq_le_ppc64
#define helper_atomic_or_fetchq_le helper_atomic_or_fetchq_le_ppc64
#define helper_atomic_xor_fetchq_le helper_atomic_xor_fetchq_le_ppc64
#define helper_atomic_fetch_sminq_le helper_atomic_fetch_sminq_le_ppc64
#define helper_atomic_fetch_uminq_le helper_atomic_fetch_uminq_le_ppc64
#define helper_atomic_fetch_smaxq_le helper_atomic_fetch_smaxq_le_ppc64
#define helper_atomic_fetch_umaxq_le helper_atomic_fetch_umaxq_le_ppc64
#define helper_atomic_smin_fetchq_le helper_atomic_smin_fetchq_le_ppc64
#define helper_atomic_umin_fetchq_le helper_atomic_umin_fetchq_le_ppc64
#define helper_atomic_smax_fetchq_le helper_atomic_smax_fetchq_le_ppc64
#define helper_atomic_umax_fetchq_le helper_atomic_umax_fetchq_le_ppc64
#define helper_atomic_cmpxchgq_be helper_atomic_cmpxchgq_be_ppc64
#define helper_atomic_xchgq_be helper_atomic_xchgq_be_ppc64
#define helper_atomic_fetch_andq_be helper_atomic_fetch_andq_be_ppc64
#define helper_atomic_fetch_orq_be helper_atomic_fetch_orq_be_ppc64
#define helper_atomic_fetch_xorq_be helper_atomic_fetch_xorq_be_ppc64
#define helper_atomic_and_fetchq_be helper_atomic_and_fetchq_be_ppc64
#define helper_atomic_or_fetchq_be helper_atomic_or_fetchq_be_ppc64
#define helper_atomic_xor_fetchq_be helper_atomic_xor_fetchq_be_ppc64
#define helper_atomic_fetch_sminq_be helper_atomic_fetch_sminq_be_ppc64
#define helper_atomic_fetch_uminq_be helper_atomic_fetch_uminq_be_ppc64
#define helper_atomic_fetch_smaxq_be helper_atomic_fetch_smaxq_be_ppc64
#define helper_atomic_fetch_umaxq_be helper_atomic_fetch_umaxq_be_ppc64
#define helper_atomic_smin_fetchq_be helper_atomic_smin_fetchq_be_ppc64
#define helper_atomic_umin_fetchq_be helper_atomic_umin_fetchq_be_ppc64
#define helper_atomic_smax_fetchq_be helper_atomic_smax_fetchq_be_ppc64
#define helper_atomic_umax_fetchq_be helper_atomic_umax_fetchq_be_ppc64
#define helper_atomic_fetch_addq_be helper_atomic_fetch_addq_be_ppc64
#define helper_atomic_add_fetchq_be helper_atomic_add_fetchq_be_ppc64
#define cpu_ldub_code cpu_ldub_code_ppc64
#define cpu_lduw_code cpu_lduw_code_ppc64
#define cpu_ldl_code cpu_ldl_code_ppc64
#define cpu_ldq_code cpu_ldq_code_ppc64
#define helper_div_i32 helper_div_i32_ppc64
#define helper_rem_i32 helper_rem_i32_ppc64
#define helper_divu_i32 helper_divu_i32_ppc64
#define helper_remu_i32 helper_remu_i32_ppc64
#define helper_shl_i64 helper_shl_i64_ppc64
#define helper_shr_i64 helper_shr_i64_ppc64
#define helper_sar_i64 helper_sar_i64_ppc64
#define helper_div_i64 helper_div_i64_ppc64
#define helper_rem_i64 helper_rem_i64_ppc64
#define helper_divu_i64 helper_divu_i64_ppc64
#define helper_remu_i64 helper_remu_i64_ppc64
#define helper_muluh_i64 helper_muluh_i64_ppc64
#define helper_mulsh_i64 helper_mulsh_i64_ppc64
#define helper_clz_i32 helper_clz_i32_ppc64
#define helper_ctz_i32 helper_ctz_i32_ppc64
#define helper_clz_i64 helper_clz_i64_ppc64
#define helper_ctz_i64 helper_ctz_i64_ppc64
#define helper_clrsb_i32 helper_clrsb_i32_ppc64
#define helper_clrsb_i64 helper_clrsb_i64_ppc64
#define helper_ctpop_i32 helper_ctpop_i32_ppc64
#define helper_ctpop_i64 helper_ctpop_i64_ppc64
#define helper_lookup_tb_ptr helper_lookup_tb_ptr_ppc64
#define helper_exit_atomic helper_exit_atomic_ppc64
#define helper_gvec_add8 helper_gvec_add8_ppc64
#define helper_gvec_add16 helper_gvec_add16_ppc64
#define helper_gvec_add32 helper_gvec_add32_ppc64
#define helper_gvec_add64 helper_gvec_add64_ppc64
#define helper_gvec_adds8 helper_gvec_adds8_ppc64
#define helper_gvec_adds16 helper_gvec_adds16_ppc64
#define helper_gvec_adds32 helper_gvec_adds32_ppc64
#define helper_gvec_adds64 helper_gvec_adds64_ppc64
#define helper_gvec_sub8 helper_gvec_sub8_ppc64
#define helper_gvec_sub16 helper_gvec_sub16_ppc64
#define helper_gvec_sub32 helper_gvec_sub32_ppc64
#define helper_gvec_sub64 helper_gvec_sub64_ppc64
#define helper_gvec_subs8 helper_gvec_subs8_ppc64
#define helper_gvec_subs16 helper_gvec_subs16_ppc64
#define helper_gvec_subs32 helper_gvec_subs32_ppc64
#define helper_gvec_subs64 helper_gvec_subs64_ppc64
#define helper_gvec_mul8 helper_gvec_mul8_ppc64
#define helper_gvec_mul16 helper_gvec_mul16_ppc64
#define helper_gvec_mul32 helper_gvec_mul32_ppc64
#define helper_gvec_mul64 helper_gvec_mul64_ppc64
#define helper_gvec_muls8 helper_gvec_muls8_ppc64
#define helper_gvec_muls16 helper_gvec_muls16_ppc64
#define helper_gvec_muls32 helper_gvec_muls32_ppc64
#define helper_gvec_muls64 helper_gvec_muls64_ppc64
#define helper_gvec_neg8 helper_gvec_neg8_ppc64
#define helper_gvec_neg16 helper_gvec_neg16_ppc64
#define helper_gvec_neg32 helper_gvec_neg32_ppc64
#define helper_gvec_neg64 helper_gvec_neg64_ppc64
#define helper_gvec_abs8 helper_gvec_abs8_ppc64
#define helper_gvec_abs16 helper_gvec_abs16_ppc64
#define helper_gvec_abs32 helper_gvec_abs32_ppc64
#define helper_gvec_abs64 helper_gvec_abs64_ppc64
#define helper_gvec_mov helper_gvec_mov_ppc64
#define helper_gvec_dup64 helper_gvec_dup64_ppc64
#define helper_gvec_dup32 helper_gvec_dup32_ppc64
#define helper_gvec_dup16 helper_gvec_dup16_ppc64
#define helper_gvec_dup8 helper_gvec_dup8_ppc64
#define helper_gvec_not helper_gvec_not_ppc64
#define helper_gvec_and helper_gvec_and_ppc64
#define helper_gvec_or helper_gvec_or_ppc64
#define helper_gvec_xor helper_gvec_xor_ppc64
#define helper_gvec_andc helper_gvec_andc_ppc64
#define helper_gvec_orc helper_gvec_orc_ppc64
#define helper_gvec_nand helper_gvec_nand_ppc64
#define helper_gvec_nor helper_gvec_nor_ppc64
#define helper_gvec_eqv helper_gvec_eqv_ppc64
#define helper_gvec_ands helper_gvec_ands_ppc64
#define helper_gvec_xors helper_gvec_xors_ppc64
#define helper_gvec_ors helper_gvec_ors_ppc64
#define helper_gvec_shl8i helper_gvec_shl8i_ppc64
#define helper_gvec_shl16i helper_gvec_shl16i_ppc64
#define helper_gvec_shl32i helper_gvec_shl32i_ppc64
#define helper_gvec_shl64i helper_gvec_shl64i_ppc64
#define helper_gvec_shr8i helper_gvec_shr8i_ppc64
#define helper_gvec_shr16i helper_gvec_shr16i_ppc64
#define helper_gvec_shr32i helper_gvec_shr32i_ppc64
#define helper_gvec_shr64i helper_gvec_shr64i_ppc64
#define helper_gvec_sar8i helper_gvec_sar8i_ppc64
#define helper_gvec_sar16i helper_gvec_sar16i_ppc64
#define helper_gvec_sar32i helper_gvec_sar32i_ppc64
#define helper_gvec_sar64i helper_gvec_sar64i_ppc64
#define helper_gvec_shl8v helper_gvec_shl8v_ppc64
#define helper_gvec_shl16v helper_gvec_shl16v_ppc64
#define helper_gvec_shl32v helper_gvec_shl32v_ppc64
#define helper_gvec_shl64v helper_gvec_shl64v_ppc64
#define helper_gvec_shr8v helper_gvec_shr8v_ppc64
#define helper_gvec_shr16v helper_gvec_shr16v_ppc64
#define helper_gvec_shr32v helper_gvec_shr32v_ppc64
#define helper_gvec_shr64v helper_gvec_shr64v_ppc64
#define helper_gvec_sar8v helper_gvec_sar8v_ppc64
#define helper_gvec_sar16v helper_gvec_sar16v_ppc64
#define helper_gvec_sar32v helper_gvec_sar32v_ppc64
#define helper_gvec_sar64v helper_gvec_sar64v_ppc64
#define helper_gvec_eq8 helper_gvec_eq8_ppc64
#define helper_gvec_ne8 helper_gvec_ne8_ppc64
#define helper_gvec_lt8 helper_gvec_lt8_ppc64
#define helper_gvec_le8 helper_gvec_le8_ppc64
#define helper_gvec_ltu8 helper_gvec_ltu8_ppc64
#define helper_gvec_leu8 helper_gvec_leu8_ppc64
#define helper_gvec_eq16 helper_gvec_eq16_ppc64
#define helper_gvec_ne16 helper_gvec_ne16_ppc64
#define helper_gvec_lt16 helper_gvec_lt16_ppc64
#define helper_gvec_le16 helper_gvec_le16_ppc64
#define helper_gvec_ltu16 helper_gvec_ltu16_ppc64
#define helper_gvec_leu16 helper_gvec_leu16_ppc64
#define helper_gvec_eq32 helper_gvec_eq32_ppc64
#define helper_gvec_ne32 helper_gvec_ne32_ppc64
#define helper_gvec_lt32 helper_gvec_lt32_ppc64
#define helper_gvec_le32 helper_gvec_le32_ppc64
#define helper_gvec_ltu32 helper_gvec_ltu32_ppc64
#define helper_gvec_leu32 helper_gvec_leu32_ppc64
#define helper_gvec_eq64 helper_gvec_eq64_ppc64
#define helper_gvec_ne64 helper_gvec_ne64_ppc64
#define helper_gvec_lt64 helper_gvec_lt64_ppc64
#define helper_gvec_le64 helper_gvec_le64_ppc64
#define helper_gvec_ltu64 helper_gvec_ltu64_ppc64
#define helper_gvec_leu64 helper_gvec_leu64_ppc64
#define helper_gvec_ssadd8 helper_gvec_ssadd8_ppc64
#define helper_gvec_ssadd16 helper_gvec_ssadd16_ppc64
#define helper_gvec_ssadd32 helper_gvec_ssadd32_ppc64
#define helper_gvec_ssadd64 helper_gvec_ssadd64_ppc64
#define helper_gvec_sssub8 helper_gvec_sssub8_ppc64
#define helper_gvec_sssub16 helper_gvec_sssub16_ppc64
#define helper_gvec_sssub32 helper_gvec_sssub32_ppc64
#define helper_gvec_sssub64 helper_gvec_sssub64_ppc64
#define helper_gvec_usadd8 helper_gvec_usadd8_ppc64
#define helper_gvec_usadd16 helper_gvec_usadd16_ppc64
#define helper_gvec_usadd32 helper_gvec_usadd32_ppc64
#define helper_gvec_usadd64 helper_gvec_usadd64_ppc64
#define helper_gvec_ussub8 helper_gvec_ussub8_ppc64
#define helper_gvec_ussub16 helper_gvec_ussub16_ppc64
#define helper_gvec_ussub32 helper_gvec_ussub32_ppc64
#define helper_gvec_ussub64 helper_gvec_ussub64_ppc64
#define helper_gvec_smin8 helper_gvec_smin8_ppc64
#define helper_gvec_smin16 helper_gvec_smin16_ppc64
#define helper_gvec_smin32 helper_gvec_smin32_ppc64
#define helper_gvec_smin64 helper_gvec_smin64_ppc64
#define helper_gvec_smax8 helper_gvec_smax8_ppc64
#define helper_gvec_smax16 helper_gvec_smax16_ppc64
#define helper_gvec_smax32 helper_gvec_smax32_ppc64
#define helper_gvec_smax64 helper_gvec_smax64_ppc64
#define helper_gvec_umin8 helper_gvec_umin8_ppc64
#define helper_gvec_umin16 helper_gvec_umin16_ppc64
#define helper_gvec_umin32 helper_gvec_umin32_ppc64
#define helper_gvec_umin64 helper_gvec_umin64_ppc64
#define helper_gvec_umax8 helper_gvec_umax8_ppc64
#define helper_gvec_umax16 helper_gvec_umax16_ppc64
#define helper_gvec_umax32 helper_gvec_umax32_ppc64
#define helper_gvec_umax64 helper_gvec_umax64_ppc64
#define helper_gvec_bitsel helper_gvec_bitsel_ppc64
#define cpu_restore_state cpu_restore_state_ppc64
#define page_collection_lock page_collection_lock_ppc64
#define page_collection_unlock page_collection_unlock_ppc64
#define free_code_gen_buffer free_code_gen_buffer_ppc64
#define tcg_exec_init tcg_exec_init_ppc64
#define tb_cleanup tb_cleanup_ppc64
#define tb_flush tb_flush_ppc64
#define tb_phys_invalidate tb_phys_invalidate_ppc64
#define tb_gen_code tb_gen_code_ppc64
#define tb_exec_lock tb_exec_lock_ppc64
#define tb_exec_unlock tb_exec_unlock_ppc64
#define tb_invalidate_phys_page_range tb_invalidate_phys_page_range_ppc64
#define tb_invalidate_phys_range tb_invalidate_phys_range_ppc64
#define tb_invalidate_phys_page_fast tb_invalidate_phys_page_fast_ppc64
#define tb_check_watchpoint tb_check_watchpoint_ppc64
#define cpu_io_recompile cpu_io_recompile_ppc64
#define tb_flush_jmp_cache tb_flush_jmp_cache_ppc64
#define tcg_flush_softmmu_tlb tcg_flush_softmmu_tlb_ppc64
#define translator_loop_temp_check translator_loop_temp_check_ppc64
#define translator_loop translator_loop_ppc64
#define helper_atomic_cmpxchgo_le_mmu helper_atomic_cmpxchgo_le_mmu_ppc64
#define helper_atomic_cmpxchgo_be_mmu helper_atomic_cmpxchgo_be_mmu_ppc64
#define helper_atomic_ldo_le_mmu helper_atomic_ldo_le_mmu_ppc64
#define helper_atomic_ldo_be_mmu helper_atomic_ldo_be_mmu_ppc64
#define helper_atomic_sto_le_mmu helper_atomic_sto_le_mmu_ppc64
#define helper_atomic_sto_be_mmu helper_atomic_sto_be_mmu_ppc64
#define unassigned_mem_ops unassigned_mem_ops_ppc64
#define floatx80_infinity floatx80_infinity_ppc64
#define dup_const_func dup_const_func_ppc64
#define gen_helper_raise_exception gen_helper_raise_exception_ppc64
#define gen_helper_raise_interrupt gen_helper_raise_interrupt_ppc64
#define gen_helper_vfp_get_fpscr gen_helper_vfp_get_fpscr_ppc64
#define gen_helper_vfp_set_fpscr gen_helper_vfp_set_fpscr_ppc64
#define gen_helper_cpsr_read gen_helper_cpsr_read_ppc64
#define gen_helper_cpsr_write gen_helper_cpsr_write_ppc64
#define tlb_reset_dirty_by_vaddr tlb_reset_dirty_by_vaddr_ppc64
#define helper_stqcx_le_parallel helper_stqcx_le_parallel_ppc64
#define helper_stqcx_be_parallel helper_stqcx_be_parallel_ppc64
#define ppc_cpu_unrealize ppc_cpu_unrealize_ppc64
#define ppc_cpu_instance_finalize ppc_cpu_instance_finalize_ppc64
#define ppc_cpu_do_interrupt ppc_cpu_do_interrupt_ppc64
#define ppc_cpu_do_system_reset ppc_cpu_do_system_reset_ppc64
#define ppc_cpu_do_fwnmi_machine_check ppc_cpu_do_fwnmi_machine_check_ppc64
#define ppc_cpu_exec_interrupt ppc_cpu_exec_interrupt_ppc64
#define raise_exception_err_ra raise_exception_err_ra_ppc64
#define raise_exception_err raise_exception_err_ppc64
#define raise_exception raise_exception_ppc64
#define raise_exception_ra raise_exception_ra_ppc64
#define helper_raise_exception_err helper_raise_exception_err_ppc64
#define helper_store_msr helper_store_msr_ppc64
#define helper_rfi helper_rfi_ppc64
#define helper_40x_rfci helper_40x_rfci_ppc64
#define helper_rfdi helper_rfdi_ppc64
#define helper_rfci helper_rfci_ppc64
#define helper_rfmci helper_rfmci_ppc64
#define helper_tw helper_tw_ppc64
#define helper_rfsvc helper_rfsvc_ppc64
#define helper_msgclr helper_msgclr_ppc64
#define helper_msgsnd helper_msgsnd_ppc64
#define helper_book3s_msgclr helper_book3s_msgclr_ppc64
#define ppc_cpu_do_unaligned_access ppc_cpu_do_unaligned_access_ppc64
#define helper_divweu helper_divweu_ppc64
#define helper_divwe helper_divwe_ppc64
#define helper_sraw helper_sraw_ppc64
#define helper_popcntb helper_popcntb_ppc64
#define helper_div helper_div_ppc64
#define helper_divo helper_divo_ppc64
#define helper_divs helper_divs_ppc64
#define helper_divso helper_divso_ppc64
#define helper_602_mfrom helper_602_mfrom_ppc64
#define helper_mtvscr helper_mtvscr_ppc64
#define helper_vaddcuw helper_vaddcuw_ppc64
#define helper_vprtybw helper_vprtybw_ppc64
#define helper_vprtybd helper_vprtybd_ppc64
#define helper_vprtybq helper_vprtybq_ppc64
#define helper_vmuluwm helper_vmuluwm_ppc64
#define helper_vaddfp helper_vaddfp_ppc64
#define helper_vsubfp helper_vsubfp_ppc64
#define helper_vminfp helper_vminfp_ppc64
#define helper_vmaxfp helper_vmaxfp_ppc64
#define helper_vmaddfp helper_vmaddfp_ppc64
#define helper_vnmsubfp helper_vnmsubfp_ppc64
#define helper_vaddsbs helper_vaddsbs_ppc64
#define helper_vsubsbs helper_vsubsbs_ppc64
#define helper_vsubshs helper_vsubshs_ppc64
#define helper_vaddsws helper_vaddsws_ppc64
#define helper_vsubsws helper_vsubsws_ppc64
#define helper_vaddubs helper_vaddubs_ppc64
#define helper_vsububs helper_vsububs_ppc64
#define helper_vadduhs helper_vadduhs_ppc64
#define helper_vsubuhs helper_vsubuhs_ppc64
#define helper_vadduws helper_vadduws_ppc64
#define helper_vsubuws helper_vsubuws_ppc64
#define helper_vavgsb helper_vavgsb_ppc64
#define helper_vavgub helper_vavgub_ppc64
#define helper_vavgsh helper_vavgsh_ppc64
#define helper_vavguh helper_vavguh_ppc64
#define helper_vavgsw helper_vavgsw_ppc64
#define helper_vabsdub helper_vabsdub_ppc64
#define helper_vabsduh helper_vabsduh_ppc64
#define helper_vabsduw helper_vabsduw_ppc64
#define helper_vcfux helper_vcfux_ppc64
#define helper_vcfsx helper_vcfsx_ppc64
#define helper_vcmpequb helper_vcmpequb_ppc64
#define helper_vcmpequb_dot helper_vcmpequb_dot_ppc64
#define helper_vcmpequw helper_vcmpequw_ppc64
#define helper_vcmpequw_dot helper_vcmpequw_dot_ppc64
#define helper_vcmpequd helper_vcmpequd_ppc64
#define helper_vcmpequd_dot helper_vcmpequd_dot_ppc64
#define helper_vcmpgtub helper_vcmpgtub_ppc64
#define helper_vcmpgtub_dot helper_vcmpgtub_dot_ppc64
#define helper_vcmpgtuh helper_vcmpgtuh_ppc64
#define helper_vcmpgtuh_dot helper_vcmpgtuh_dot_ppc64
#define helper_vcmpgtuw helper_vcmpgtuw_ppc64
#define helper_vcmpgtuw_dot helper_vcmpgtuw_dot_ppc64
#define helper_vcmpgtud helper_vcmpgtud_ppc64
#define helper_vcmpgtud_dot helper_vcmpgtud_dot_ppc64
#define helper_vcmpgtud helper_vcmpgtud_ppc64
#define helper_vcmpgtud_dot helper_vcmpgtud_dot_ppc64
#define helper_vcmpgtsb helper_vcmpgtsb_ppc64
#define helper_vcmpgtsb_dot helper_vcmpgtsb_dot_ppc64
#define helper_vcmpgtsh helper_vcmpgtsh_ppc64
#define helper_vcmpgtsh_dot helper_vcmpgtsh_dot_ppc64
#define helper_vcmpgtsw helper_vcmpgtsw_ppc64
#define helper_vcmpgtsw_dot helper_vcmpgtsw_dot_ppc64
#define helper_vcmpgtsd helper_vcmpgtsd_ppc64
#define helper_vcmpgtsd_dot helper_vcmpgtsd_dot_ppc64
#define helper_vcmpnezb helper_vcmpnezb_ppc64
#define helper_vcmpnezb_dot helper_vcmpnezb_dot_ppc64
#define helper_vcmpnezb helper_vcmpnezb_ppc64
#define helper_vcmpnezb_dot helper_vcmpnezb_dot_ppc64
#define helper_vcmpnezw helper_vcmpnezw_ppc64
#define helper_vcmpnezw_dot helper_vcmpnezw_dot_ppc64
#define helper_vcmpneb helper_vcmpneb_ppc64
#define helper_vcmpneb_dot helper_vcmpneb_dot_ppc64
#define helper_vcmpneb helper_vcmpneb_ppc64
#define helper_vcmpneb_dot helper_vcmpneb_dot_ppc64
#define helper_vcmpneh helper_vcmpneh_ppc64
#define helper_vcmpneh_dot helper_vcmpneh_dot_ppc64
#define helper_vcmpnew helper_vcmpnew_ppc64
#define helper_vcmpnew_dot helper_vcmpnew_dot_ppc64
#define helper_vcmpeqfp helper_vcmpeqfp_ppc64
#define helper_vcmpeqfp_dot helper_vcmpeqfp_dot_ppc64
#define helper_vcmpgefp helper_vcmpgefp_ppc64
#define helper_vcmpgefp_dot helper_vcmpgefp_dot_ppc64
#define helper_vcmpgtfp helper_vcmpgtfp_ppc64
#define helper_vcmpgtfp_dot helper_vcmpgtfp_dot_ppc64
#define helper_vcmpbfp helper_vcmpbfp_ppc64
#define helper_vcmpbfp_dot helper_vcmpbfp_dot_ppc64
#define helper_vcmpbfp helper_vcmpbfp_ppc64
#define helper_vcmpbfp_dot helper_vcmpbfp_dot_ppc64
#define helper_vctuxs helper_vctuxs_ppc64
#define helper_vctsxs helper_vctsxs_ppc64
#define helper_vclzlsbb helper_vclzlsbb_ppc64
#define helper_vctzlsbb helper_vctzlsbb_ppc64
#define helper_vmhaddshs helper_vmhaddshs_ppc64
#define helper_vmhraddshs helper_vmhraddshs_ppc64
#define helper_vmladduhm helper_vmladduhm_ppc64
#define helper_vmhraddshs helper_vmhraddshs_ppc64
#define helper_vmladduhm helper_vmladduhm_ppc64
#define helper_vmrglb helper_vmrglb_ppc64
#define helper_vmrghb helper_vmrghb_ppc64
#define helper_vmrglh helper_vmrglh_ppc64
#define helper_vmrghh helper_vmrghh_ppc64
#define helper_vmrglw helper_vmrglw_ppc64
#define helper_vmrghw helper_vmrghw_ppc64
#define helper_vmsummbm helper_vmsummbm_ppc64
#define helper_vmsumshs helper_vmsumshs_ppc64
#define helper_vmsumubm helper_vmsumubm_ppc64
#define helper_vmsumuhm helper_vmsumuhm_ppc64
#define helper_vmulesb helper_vmulesb_ppc64
#define helper_vmulosb helper_vmulosb_ppc64
#define helper_vmulesh helper_vmulesh_ppc64
#define helper_vmulesw helper_vmulesw_ppc64
#define helper_vmuleub helper_vmuleub_ppc64
#define helper_vmuloub helper_vmuloub_ppc64
#define helper_vmuleuh helper_vmuleuh_ppc64
#define helper_vmulouh helper_vmulouh_ppc64
#define helper_vmuleuw helper_vmuleuw_ppc64
#define helper_vmulouw helper_vmulouw_ppc64
#define helper_vperm helper_vperm_ppc64
#define helper_vpermr helper_vpermr_ppc64
#define helper_vbpermd helper_vbpermd_ppc64
#define helper_vpmsumb helper_vpmsumb_ppc64
#define helper_vpmsumh helper_vpmsumh_ppc64
#define helper_vpmsumw helper_vpmsumw_ppc64
#define helper_vpmsumd helper_vpmsumd_ppc64
#define helper_vpkpx helper_vpkpx_ppc64
#define helper_vpkshss helper_vpkshss_ppc64
#define helper_vpkshus helper_vpkshus_ppc64
#define helper_vpkswss helper_vpkswss_ppc64
#define helper_vpkswus helper_vpkswus_ppc64
#define helper_vpksdss helper_vpksdss_ppc64
#define helper_vpksdus helper_vpksdus_ppc64
#define helper_vpkuhus helper_vpkuhus_ppc64
#define helper_vpkuwus helper_vpkuwus_ppc64
#define helper_vpkudus helper_vpkudus_ppc64
#define helper_vpkuhum helper_vpkuhum_ppc64
#define helper_vpkuwum helper_vpkuwum_ppc64
#define helper_vpkudum helper_vpkudum_ppc64
#define helper_vrefp helper_vrefp_ppc64
#define helper_vrfin helper_vrfin_ppc64
#define helper_vrfim helper_vrfim_ppc64
#define helper_vrfip helper_vrfip_ppc64
#define helper_vrfiz helper_vrfiz_ppc64
#define helper_vrlb helper_vrlb_ppc64
#define helper_vrlh helper_vrlh_ppc64
#define helper_vrlw helper_vrlw_ppc64
#define helper_vrld helper_vrld_ppc64
#define helper_vrsqrtefp helper_vrsqrtefp_ppc64
#define helper_vrldmi helper_vrldmi_ppc64
#define helper_vrlwmi helper_vrlwmi_ppc64
#define helper_vrldnm helper_vrldnm_ppc64
#define helper_vrlwnm helper_vrlwnm_ppc64
#define helper_vsel helper_vsel_ppc64
#define helper_vexptefp helper_vexptefp_ppc64
#define helper_vlogefp helper_vlogefp_ppc64
#define helper_vextublx helper_vextublx_ppc64
#define helper_vextuhlx helper_vextuhlx_ppc64
#define helper_vextuwlx helper_vextuwlx_ppc64
#define helper_vextubrx helper_vextubrx_ppc64
#define helper_vextuhrx helper_vextuhrx_ppc64
#define helper_vextuwrx helper_vextuwrx_ppc64
#define helper_vslv helper_vslv_ppc64
#define helper_vsrv helper_vsrv_ppc64
#define helper_vsldoi helper_vsldoi_ppc64
#define helper_vslo helper_vslo_ppc64
#define helper_vinsertb helper_vinsertb_ppc64
#define helper_vinserth helper_vinserth_ppc64
#define helper_vinsertw helper_vinsertw_ppc64
#define helper_vinsertd helper_vinsertd_ppc64
#define helper_vextractub helper_vextractub_ppc64
#define helper_vextractuh helper_vextractuh_ppc64
#define helper_vextractuw helper_vextractuw_ppc64
#define helper_vextractd helper_vextractd_ppc64
#define helper_xxextractuw helper_xxextractuw_ppc64
#define helper_xxinsertw helper_xxinsertw_ppc64
#define helper_vextsb2w helper_vextsb2w_ppc64
#define helper_vextsb2d helper_vextsb2d_ppc64
#define helper_vextsh2w helper_vextsh2w_ppc64
#define helper_vextsh2d helper_vextsh2d_ppc64
#define helper_vnegw helper_vnegw_ppc64
#define helper_vnegd helper_vnegd_ppc64
#define helper_vsro helper_vsro_ppc64
#define helper_vsubcuw helper_vsubcuw_ppc64
#define helper_vsumsws helper_vsumsws_ppc64
#define helper_vsum2sws helper_vsum2sws_ppc64
#define helper_vsum4sbs helper_vsum4sbs_ppc64
#define helper_vsum4shs helper_vsum4shs_ppc64
#define helper_vsum4ubs helper_vsum4ubs_ppc64
#define helper_vupklpx helper_vupklpx_ppc64
#define helper_vupkhpx helper_vupkhpx_ppc64
#define helper_vupkhsb helper_vupkhsb_ppc64
#define helper_vupkhsh helper_vupkhsh_ppc64
#define helper_vupkhsw helper_vupkhsw_ppc64
#define helper_vupklsb helper_vupklsb_ppc64
#define helper_vupklsh helper_vupklsh_ppc64
#define helper_vupklsw helper_vupklsw_ppc64
#define helper_vclzb helper_vclzb_ppc64
#define helper_vclzh helper_vclzh_ppc64
#define helper_vctzb helper_vctzb_ppc64
#define helper_vctzh helper_vctzh_ppc64
#define helper_vctzw helper_vctzw_ppc64
#define helper_vctzd helper_vctzd_ppc64
#define helper_vpopcntb helper_vpopcntb_ppc64
#define helper_vpopcnth helper_vpopcnth_ppc64
#define helper_vpopcntw helper_vpopcntw_ppc64
#define helper_vpopcntd helper_vpopcntd_ppc64
#define helper_vadduqm helper_vadduqm_ppc64
#define helper_vaddeuqm helper_vaddeuqm_ppc64
#define helper_vaddcuq helper_vaddcuq_ppc64
#define helper_vaddecuq helper_vaddecuq_ppc64
#define helper_vsubuqm helper_vsubuqm_ppc64
#define helper_vsubeuqm helper_vsubeuqm_ppc64
#define helper_vsubcuq helper_vsubcuq_ppc64
#define helper_vsubecuq helper_vsubecuq_ppc64
#define helper_bcdadd helper_bcdadd_ppc64
#define helper_bcdsub helper_bcdsub_ppc64
#define helper_bcdcfn helper_bcdcfn_ppc64
#define helper_bcdctn helper_bcdctn_ppc64
#define helper_bcdcfz helper_bcdcfz_ppc64
#define helper_bcdctz helper_bcdctz_ppc64
#define helper_bcdcfsq helper_bcdcfsq_ppc64
#define helper_bcdctsq helper_bcdctsq_ppc64
#define helper_bcdcpsgn helper_bcdcpsgn_ppc64
#define helper_bcdsetsgn helper_bcdsetsgn_ppc64
#define helper_bcds helper_bcds_ppc64
#define helper_bcdus helper_bcdus_ppc64
#define helper_bcdsr helper_bcdsr_ppc64
#define helper_bcdtrunc helper_bcdtrunc_ppc64
#define helper_bcdutrunc helper_bcdutrunc_ppc64
#define helper_vsbox helper_vsbox_ppc64
#define helper_vcipher helper_vcipher_ppc64
#define helper_vcipherlast helper_vcipherlast_ppc64
#define helper_vncipher helper_vncipher_ppc64
#define helper_vncipherlast helper_vncipherlast_ppc64
#define helper_vshasigmaw helper_vshasigmaw_ppc64
#define helper_vshasigmad helper_vshasigmad_ppc64
#define helper_vpermxor helper_vpermxor_ppc64
#define helper_brinc helper_brinc_ppc64
#define helper_cntlsw32 helper_cntlsw32_ppc64
#define helper_cntlzw32 helper_cntlzw32_ppc64
#define helper_dlmzb helper_dlmzb_ppc64
#define helper_lmw helper_lmw_ppc64
#define helper_lsw helper_lsw_ppc64
#define helper_lswx helper_lswx_ppc64
#define helper_stsw helper_stsw_ppc64
#define helper_dcbz helper_dcbz_ppc64
#define helper_dcbzep helper_dcbzep_ppc64
#define helper_icbi helper_icbi_ppc64
#define helper_icbiep helper_icbiep_ppc64
#define helper_lscbx helper_lscbx_ppc64
#define helper_lvebx helper_lvebx_ppc64
#define helper_lvehx helper_lvehx_ppc64
#define helper_lvewx helper_lvewx_ppc64
#define helper_stvebx helper_stvebx_ppc64
#define helper_stvehx helper_stvehx_ppc64
#define helper_stvewx helper_stvewx_ppc64
#define helper_tbegin helper_tbegin_ppc64
#define helper_load_dump_spr helper_load_dump_spr_ppc64
#define helper_store_dump_spr helper_store_dump_spr_ppc64
#define helper_hfscr_facility_check helper_hfscr_facility_check_ppc64
#define helper_fscr_facility_check helper_fscr_facility_check_ppc64
#define helper_msr_facility_check helper_msr_facility_check_ppc64
#define helper_store_sdr1 helper_store_sdr1_ppc64
#define helper_store_pidr helper_store_pidr_ppc64
#define helper_store_lpidr helper_store_lpidr_ppc64
#define helper_store_hid0_601 helper_store_hid0_601_ppc64
#define helper_store_403_pbr helper_store_403_pbr_ppc64
#define helper_store_40x_dbcr0 helper_store_40x_dbcr0_ppc64
#define helper_store_40x_sler helper_store_40x_sler_ppc64
#define helper_clcs helper_clcs_ppc64
#define ppc_store_msr ppc_store_msr_ppc64
#define helper_fixup_thrm helper_fixup_thrm_ppc64
#define store_40x_sler store_40x_sler_ppc64
#define dump_mmu dump_mmu_ppc64
#define ppc_cpu_get_phys_page_debug ppc_cpu_get_phys_page_debug_ppc64
#define helper_store_ibatu helper_store_ibatu_ppc64
#define helper_store_ibatl helper_store_ibatl_ppc64
#define helper_store_dbatu helper_store_dbatu_ppc64
#define helper_store_dbatl helper_store_dbatl_ppc64
#define helper_store_601_batu helper_store_601_batu_ppc64
#define helper_store_601_batl helper_store_601_batl_ppc64
#define ppc_tlb_invalidate_all ppc_tlb_invalidate_all_ppc64
#define ppc_tlb_invalidate_one ppc_tlb_invalidate_one_ppc64
#define ppc_store_sdr1 ppc_store_sdr1_ppc64
#define helper_load_sr helper_load_sr_ppc64
#define helper_store_sr helper_store_sr_ppc64
#define helper_tlbia helper_tlbia_ppc64
#define helper_tlbie helper_tlbie_ppc64
#define helper_tlbiva helper_tlbiva_ppc64
#define helper_6xx_tlbd helper_6xx_tlbd_ppc64
#define helper_6xx_tlbi helper_6xx_tlbi_ppc64
#define helper_74xx_tlbd helper_74xx_tlbd_ppc64
#define helper_74xx_tlbi helper_74xx_tlbi_ppc64
#define helper_rac helper_rac_ppc64
#define helper_4xx_tlbre_hi helper_4xx_tlbre_hi_ppc64
#define helper_4xx_tlbre_lo helper_4xx_tlbre_lo_ppc64
#define helper_4xx_tlbwe_hi helper_4xx_tlbwe_hi_ppc64
#define helper_4xx_tlbwe_lo helper_4xx_tlbwe_lo_ppc64
#define helper_4xx_tlbsx helper_4xx_tlbsx_ppc64
#define helper_440_tlbwe helper_440_tlbwe_ppc64
#define helper_440_tlbre helper_440_tlbre_ppc64
#define helper_440_tlbsx helper_440_tlbsx_ppc64
#define helper_booke_setpid helper_booke_setpid_ppc64
#define helper_booke_set_eplc helper_booke_set_eplc_ppc64
#define helper_booke_set_epsc helper_booke_set_epsc_ppc64
#define helper_booke206_tlbwe helper_booke206_tlbwe_ppc64
#define helper_booke206_tlbre helper_booke206_tlbre_ppc64
#define helper_booke206_tlbsx helper_booke206_tlbsx_ppc64
#define helper_booke206_tlbivax helper_booke206_tlbivax_ppc64
#define helper_booke206_tlbilx0 helper_booke206_tlbilx0_ppc64
#define helper_booke206_tlbilx1 helper_booke206_tlbilx1_ppc64
#define helper_booke206_tlbilx3 helper_booke206_tlbilx3_ppc64
#define helper_booke206_tlbflush helper_booke206_tlbflush_ppc64
#define helper_check_tlb_flush_local helper_check_tlb_flush_local_ppc64
#define helper_check_tlb_flush_global helper_check_tlb_flush_global_ppc64
#define ppc_cpu_tlb_fill ppc_cpu_tlb_fill_ppc64
#define helper_load_tbl helper_load_tbl_ppc64
#define helper_load_tbu helper_load_tbu_ppc64
#define helper_load_atbl helper_load_atbl_ppc64
#define helper_load_atbu helper_load_atbu_ppc64
#define helper_load_vtb helper_load_vtb_ppc64
#define helper_load_601_rtcl helper_load_601_rtcl_ppc64
#define helper_load_601_rtcu helper_load_601_rtcu_ppc64
#define helper_store_tbl helper_store_tbl_ppc64
#define helper_store_tbu helper_store_tbu_ppc64
#define helper_store_atbl helper_store_atbl_ppc64
#define helper_store_atbu helper_store_atbu_ppc64
#define helper_store_601_rtcl helper_store_601_rtcl_ppc64
#define helper_store_601_rtcu helper_store_601_rtcu_ppc64
#define helper_load_decr helper_load_decr_ppc64
#define helper_store_decr helper_store_decr_ppc64
#define helper_load_hdecr helper_load_hdecr_ppc64
#define helper_store_hdecr helper_store_hdecr_ppc64
#define helper_store_vtb helper_store_vtb_ppc64
#define helper_store_tbu40 helper_store_tbu40_ppc64
#define helper_load_40x_pit helper_load_40x_pit_ppc64
#define helper_store_40x_pit helper_store_40x_pit_ppc64
#define helper_store_booke_tcr helper_store_booke_tcr_ppc64
#define helper_store_booke_tsr helper_store_booke_tsr_ppc64
#define helper_load_dcr helper_load_dcr_ppc64
#define helper_store_dcr helper_store_dcr_ppc64
#define helper_raise_exception helper_raise_exception_ppc64
#define helper_book3s_msgsnd helper_book3s_msgsnd_ppc64
#define helper_cmpb helper_cmpb_ppc64
#define helper_mfvscr helper_mfvscr_ppc64
#define helper_vaddshs helper_vaddshs_ppc64
#define helper_vavguw helper_vavguw_ppc64
#define helper_vcmpequh helper_vcmpequh_ppc64
#define helper_vcmpequh_dot helper_vcmpequh_dot_ppc64
#define helper_vcmpnezh helper_vcmpnezh_ppc64
#define helper_vcmpnezh_dot helper_vcmpnezh_dot_ppc64
#define helper_vmsumshm helper_vmsumshm_ppc64
#define helper_vmsumuhs helper_vmsumuhs_ppc64
#define helper_vmulosh helper_vmulosh_ppc64
#define helper_vmulosw helper_vmulosw_ppc64
#define helper_vbpermq helper_vbpermq_ppc64
#define helper_vextsw2d helper_vextsw2d_ppc64
#define helper_stmw helper_stmw_ppc64
#define ppc_translate_init ppc_translate_init_ppc64
#define cpu_ppc_init cpu_ppc_init_ppc64
#define gen_intermediate_code gen_intermediate_code_ppc64
#define restore_state_to_opc restore_state_to_opc_ppc64
#define ppc_set_irq ppc_set_irq_ppc64
#define ppc6xx_irq_init ppc6xx_irq_init_ppc64
#define ppc40x_core_reset ppc40x_core_reset_ppc64
#define ppc40x_chip_reset ppc40x_chip_reset_ppc64
#define ppc40x_system_reset ppc40x_system_reset_ppc64
#define store_40x_dbcr0 store_40x_dbcr0_ppc64
#define ppc40x_irq_init ppc40x_irq_init_ppc64
#define ppce500_irq_init ppce500_irq_init_ppc64
#define ppce500_set_mpic_proxy ppce500_set_mpic_proxy_ppc64
#define cpu_ppc_get_tb cpu_ppc_get_tb_ppc64
#define cpu_ppc_load_tbl cpu_ppc_load_tbl_ppc64
#define cpu_ppc_load_tbu cpu_ppc_load_tbu_ppc64
#define cpu_ppc_store_tbl cpu_ppc_store_tbl_ppc64
#define cpu_ppc_store_tbu cpu_ppc_store_tbu_ppc64
#define cpu_ppc_load_atbl cpu_ppc_load_atbl_ppc64
#define cpu_ppc_load_atbu cpu_ppc_load_atbu_ppc64
#define cpu_ppc_store_atbl cpu_ppc_store_atbl_ppc64
#define cpu_ppc_store_atbu cpu_ppc_store_atbu_ppc64
#define cpu_ppc_load_vtb cpu_ppc_load_vtb_ppc64
#define cpu_ppc_store_vtb cpu_ppc_store_vtb_ppc64
#define cpu_ppc_store_tbu40 cpu_ppc_store_tbu40_ppc64
#define ppc_decr_clear_on_delivery ppc_decr_clear_on_delivery_ppc64
#define cpu_ppc_load_decr cpu_ppc_load_decr_ppc64
#define cpu_ppc_load_hdecr cpu_ppc_load_hdecr_ppc64
#define cpu_ppc_load_purr cpu_ppc_load_purr_ppc64
#define cpu_ppc_store_decr cpu_ppc_store_decr_ppc64
#define cpu_ppc_store_hdecr cpu_ppc_store_hdecr_ppc64
#define cpu_ppc_store_purr cpu_ppc_store_purr_ppc64
#define cpu_ppc_tb_init cpu_ppc_tb_init_ppc64
#define cpu_ppc601_load_rtcu cpu_ppc601_load_rtcu_ppc64
#define cpu_ppc601_store_rtcu cpu_ppc601_store_rtcu_ppc64
#define cpu_ppc601_load_rtcl cpu_ppc601_load_rtcl_ppc64
#define cpu_ppc601_store_rtcl cpu_ppc601_store_rtcl_ppc64
#define load_40x_pit load_40x_pit_ppc64
#define store_40x_pit store_40x_pit_ppc64
#define ppc_40x_timers_init ppc_40x_timers_init_ppc64
#define ppc_dcr_read ppc_dcr_read_ppc64
#define ppc_dcr_write ppc_dcr_write_ppc64
#define ppc_dcr_register ppc_dcr_register_ppc64
#define ppc_dcr_init ppc_dcr_init_ppc64
#define ppc_cpu_pir ppc_cpu_pir_ppc64
#define ppc_irq_reset ppc_irq_reset_ppc64
#define store_booke_tsr store_booke_tsr_ppc64
#define get_pteg_offset32 get_pteg_offset32_ppc64
#define ppc_booke_timers_init ppc_booke_timers_init_ppc64
#define ppc_hash32_handle_mmu_fault ppc_hash32_handle_mmu_fault_ppc64
#define gen_helper_store_booke_tsr gen_helper_store_booke_tsr_ppc64
#define gen_helper_store_booke_tcr gen_helper_store_booke_tcr_ppc64
#define store_booke_tcr store_booke_tcr_ppc64
#define ppc_hash32_get_phys_page_debug ppc_hash32_get_phys_page_debug_ppc64
#define helper_fadd helper_fadd_ppc64
#define helper_todouble helper_todouble_ppc64
#define helper_tosingle helper_tosingle_ppc64
#define helper_compute_fprf_float16 helper_compute_fprf_float16_ppc64
#define helper_compute_fprf_float32 helper_compute_fprf_float32_ppc64
#define helper_compute_fprf_float64 helper_compute_fprf_float64_ppc64
#define helper_compute_fprf_float128 helper_compute_fprf_float128_ppc64
#define helper_fpscr_clrbit helper_fpscr_clrbit_ppc64
#define helper_fpscr_setbit helper_fpscr_setbit_ppc64
#define helper_store_fpscr helper_store_fpscr_ppc64
#define helper_float_check_status helper_float_check_status_ppc64
#define helper_reset_fpstatus helper_reset_fpstatus_ppc64
#define helper_fsub helper_fsub_ppc64
#define helper_fmul helper_fmul_ppc64
#define helper_fdiv helper_fdiv_ppc64
#define helper_fctiw helper_fctiw_ppc64
#define helper_fctiwz helper_fctiwz_ppc64
#define helper_fctiwu helper_fctiwu_ppc64
#define helper_fctiwuz helper_fctiwuz_ppc64
#define helper_fctid helper_fctid_ppc64
#define helper_fctidz helper_fctidz_ppc64
#define helper_fctidu helper_fctidu_ppc64
#define helper_fctiduz helper_fctiduz_ppc64
#define helper_fcfid helper_fcfid_ppc64
#define helper_fcfids helper_fcfids_ppc64
#define helper_fcfidu helper_fcfidu_ppc64
#define helper_fcfidus helper_fcfidus_ppc64
#define helper_frin helper_frin_ppc64
#define helper_friz helper_friz_ppc64
#define helper_frip helper_frip_ppc64
#define helper_frim helper_frim_ppc64
#define helper_fmadd helper_fmadd_ppc64
#define helper_fnmadd helper_fnmadd_ppc64
#define helper_fmsub helper_fmsub_ppc64
#define helper_fnmsub helper_fnmsub_ppc64
#define helper_frsp helper_frsp_ppc64
#define helper_fsqrt helper_fsqrt_ppc64
#define helper_fre helper_fre_ppc64
#define helper_fres helper_fres_ppc64
#define helper_frsqrte helper_frsqrte_ppc64
#define helper_fsel helper_fsel_ppc64
#define helper_ftdiv helper_ftdiv_ppc64
#define helper_ftsqrt helper_ftsqrt_ppc64
#define helper_fcmpu helper_fcmpu_ppc64
#define helper_fcmpo helper_fcmpo_ppc64
#define helper_efscfsi helper_efscfsi_ppc64
#define helper_efscfui helper_efscfui_ppc64
#define helper_efscfuf helper_efscfuf_ppc64
#define helper_efscfsf helper_efscfsf_ppc64
#define helper_efsctsi helper_efsctsi_ppc64
#define helper_efsctui helper_efsctui_ppc64
#define helper_efsctsiz helper_efsctsiz_ppc64
#define helper_efsctuiz helper_efsctuiz_ppc64
#define helper_efsctsf helper_efsctsf_ppc64
#define helper_efsctuf helper_efsctuf_ppc64
#define helper_evfscfsi helper_evfscfsi_ppc64
#define helper_evfscfui helper_evfscfui_ppc64
#define helper_evfscfuf helper_evfscfuf_ppc64
#define helper_evfscfsf helper_evfscfsf_ppc64
#define helper_evfsctsi helper_evfsctsi_ppc64
#define helper_evfsctui helper_evfsctui_ppc64
#define helper_evfsctsiz helper_evfsctsiz_ppc64
#define helper_evfsctuiz helper_evfsctuiz_ppc64
#define helper_evfsctsf helper_evfsctsf_ppc64
#define helper_evfsctuf helper_evfsctuf_ppc64
#define helper_efsadd helper_efsadd_ppc64
#define helper_efssub helper_efssub_ppc64
#define helper_efsmul helper_efsmul_ppc64
#define helper_efsdiv helper_efsdiv_ppc64
#define helper_evfsadd helper_evfsadd_ppc64
#define helper_evfssub helper_evfssub_ppc64
#define helper_evfsmul helper_evfsmul_ppc64
#define helper_evfsdiv helper_evfsdiv_ppc64
#define helper_efststlt helper_efststlt_ppc64
#define helper_efststgt helper_efststgt_ppc64
#define helper_efststeq helper_efststeq_ppc64
#define helper_efscmplt helper_efscmplt_ppc64
#define helper_efscmpgt helper_efscmpgt_ppc64
#define helper_efscmpeq helper_efscmpeq_ppc64
#define helper_evfststlt helper_evfststlt_ppc64
#define helper_evfststgt helper_evfststgt_ppc64
#define helper_evfststeq helper_evfststeq_ppc64
#define helper_evfscmplt helper_evfscmplt_ppc64
#define helper_evfscmpgt helper_evfscmpgt_ppc64
#define helper_evfscmpeq helper_evfscmpeq_ppc64
#define helper_efdcfsi helper_efdcfsi_ppc64
#define helper_efdcfsid helper_efdcfsid_ppc64
#define helper_efdcfui helper_efdcfui_ppc64
#define helper_efdcfuid helper_efdcfuid_ppc64
#define helper_efdctsi helper_efdctsi_ppc64
#define helper_efdctui helper_efdctui_ppc64
#define helper_efdctsiz helper_efdctsiz_ppc64
#define helper_efdctsidz helper_efdctsidz_ppc64
#define helper_efdctuiz helper_efdctuiz_ppc64
#define helper_efdctuidz helper_efdctuidz_ppc64
#define helper_efdcfsf helper_efdcfsf_ppc64
#define helper_efdcfuf helper_efdcfuf_ppc64
#define helper_efdctsf helper_efdctsf_ppc64
#define helper_efdctuf helper_efdctuf_ppc64
#define helper_efscfd helper_efscfd_ppc64
#define helper_efdcfs helper_efdcfs_ppc64
#define helper_efdadd helper_efdadd_ppc64
#define helper_efdsub helper_efdsub_ppc64
#define helper_efdmul helper_efdmul_ppc64
#define helper_efddiv helper_efddiv_ppc64
#define helper_efdtstlt helper_efdtstlt_ppc64
#define helper_efdtstgt helper_efdtstgt_ppc64
#define helper_efdtsteq helper_efdtsteq_ppc64
#define helper_efdcmplt helper_efdcmplt_ppc64
#define helper_efdcmpgt helper_efdcmpgt_ppc64
#define helper_efdcmpeq helper_efdcmpeq_ppc64
#define helper_xsadddp helper_xsadddp_ppc64
#define helper_xsaddsp helper_xsaddsp_ppc64
#define helper_xvadddp helper_xvadddp_ppc64
#define helper_xvaddsp helper_xvaddsp_ppc64
#define helper_xssubdp helper_xssubdp_ppc64
#define helper_xssubsp helper_xssubsp_ppc64
#define helper_xvsubdp helper_xvsubdp_ppc64
#define helper_xvsubsp helper_xvsubsp_ppc64
#define helper_xsaddqp helper_xsaddqp_ppc64
#define helper_xsmuldp helper_xsmuldp_ppc64
#define helper_xsmulsp helper_xsmulsp_ppc64
#define helper_xvmuldp helper_xvmuldp_ppc64
#define helper_xvmulsp helper_xvmulsp_ppc64
#define helper_xsmulqp helper_xsmulqp_ppc64
#define helper_xsdivdp helper_xsdivdp_ppc64
#define helper_xsdivsp helper_xsdivsp_ppc64
#define helper_xvdivdp helper_xvdivdp_ppc64
#define helper_xvdivsp helper_xvdivsp_ppc64
#define helper_xsdivqp helper_xsdivqp_ppc64
#define helper_xsredp helper_xsredp_ppc64
#define helper_xsresp helper_xsresp_ppc64
#define helper_xvredp helper_xvredp_ppc64
#define helper_xvresp helper_xvresp_ppc64
#define helper_xssqrtdp helper_xssqrtdp_ppc64
#define helper_xssqrtsp helper_xssqrtsp_ppc64
#define helper_xvsqrtdp helper_xvsqrtdp_ppc64
#define helper_xvsqrtsp helper_xvsqrtsp_ppc64
#define helper_xsrsqrtedp helper_xsrsqrtedp_ppc64
#define helper_xsrsqrtesp helper_xsrsqrtesp_ppc64
#define helper_xvrsqrtedp helper_xvrsqrtedp_ppc64
#define helper_xvrsqrtesp helper_xvrsqrtesp_ppc64
#define helper_xstdivdp helper_xstdivdp_ppc64
#define helper_xvtdivdp helper_xvtdivdp_ppc64
#define helper_xvtdivsp helper_xvtdivsp_ppc64
#define helper_xstsqrtdp helper_xstsqrtdp_ppc64
#define helper_xvtsqrtdp helper_xvtsqrtdp_ppc64
#define helper_xvtsqrtsp helper_xvtsqrtsp_ppc64
#define helper_xsmadddp helper_xsmadddp_ppc64
#define helper_xsmsubdp helper_xsmsubdp_ppc64
#define helper_xsnmadddp helper_xsnmadddp_ppc64
#define helper_xsnmsubdp helper_xsnmsubdp_ppc64
#define helper_xsmaddsp helper_xsmaddsp_ppc64
#define helper_xsmsubsp helper_xsmsubsp_ppc64
#define helper_xsnmaddsp helper_xsnmaddsp_ppc64
#define helper_xsnmsubsp helper_xsnmsubsp_ppc64
#define helper_xvmadddp helper_xvmadddp_ppc64
#define helper_xvmsubdp helper_xvmsubdp_ppc64
#define helper_xvnmadddp helper_xvnmadddp_ppc64
#define helper_xvnmsubdp helper_xvnmsubdp_ppc64
#define helper_xvmaddsp helper_xvmaddsp_ppc64
#define helper_xvmsubsp helper_xvmsubsp_ppc64
#define helper_xvnmaddsp helper_xvnmaddsp_ppc64
#define helper_xvnmsubsp helper_xvnmsubsp_ppc64
#define helper_xscmpeqdp helper_xscmpeqdp_ppc64
#define helper_xscmpgedp helper_xscmpgedp_ppc64
#define helper_xscmpgtdp helper_xscmpgtdp_ppc64
#define helper_xscmpnedp helper_xscmpnedp_ppc64
#define helper_xscmpexpdp helper_xscmpexpdp_ppc64
#define helper_xscmpexpqp helper_xscmpexpqp_ppc64
#define helper_xscmpodp helper_xscmpodp_ppc64
#define helper_xscmpudp helper_xscmpudp_ppc64
#define helper_xscmpoqp helper_xscmpoqp_ppc64
#define helper_xscmpuqp helper_xscmpuqp_ppc64
#define helper_xsmaxdp helper_xsmaxdp_ppc64
#define helper_xvmaxdp helper_xvmaxdp_ppc64
#define helper_xvmaxsp helper_xvmaxsp_ppc64
#define helper_xsmindp helper_xsmindp_ppc64
#define helper_xvmindp helper_xvmindp_ppc64
#define helper_xvminsp helper_xvminsp_ppc64
#define helper_xsmaxcdp helper_xsmaxcdp_ppc64
#define helper_xsmincdp helper_xsmincdp_ppc64
#define helper_xsmaxjdp helper_xsmaxjdp_ppc64
#define helper_xsminjdp helper_xsminjdp_ppc64
#define helper_xvcmpeqdp helper_xvcmpeqdp_ppc64
#define helper_xvcmpgedp helper_xvcmpgedp_ppc64
#define helper_xvcmpgtdp helper_xvcmpgtdp_ppc64
#define helper_xvcmpnedp helper_xvcmpnedp_ppc64
#define helper_xvcmpeqsp helper_xvcmpeqsp_ppc64
#define helper_xvcmpgesp helper_xvcmpgesp_ppc64
#define helper_xvcmpgtsp helper_xvcmpgtsp_ppc64
#define helper_xvcmpnesp helper_xvcmpnesp_ppc64
#define helper_xscvdpsp helper_xscvdpsp_ppc64
#define helper_xscvspdp helper_xscvspdp_ppc64
#define helper_xvcvdpsp helper_xvcvdpsp_ppc64
#define helper_xvcvspdp helper_xvcvspdp_ppc64
#define helper_xscvdpqp helper_xscvdpqp_ppc64
#define helper_xscvdphp helper_xscvdphp_ppc64
#define helper_xscvhpdp helper_xscvhpdp_ppc64
#define helper_xvcvsphp helper_xvcvsphp_ppc64
#define helper_xvcvhpsp helper_xvcvhpsp_ppc64
#define helper_xscvqpdp helper_xscvqpdp_ppc64
#define helper_xscvdpspn helper_xscvdpspn_ppc64
#define helper_xscvspdpn helper_xscvspdpn_ppc64
#define helper_xscvdpsxds helper_xscvdpsxds_ppc64
#define helper_xscvdpsxws helper_xscvdpsxws_ppc64
#define helper_xscvdpuxds helper_xscvdpuxds_ppc64
#define helper_xscvdpuxws helper_xscvdpuxws_ppc64
#define helper_xvcvdpsxds helper_xvcvdpsxds_ppc64
#define helper_xvcvdpsxws helper_xvcvdpsxws_ppc64
#define helper_xvcvdpuxds helper_xvcvdpuxds_ppc64
#define helper_xvcvdpuxws helper_xvcvdpuxws_ppc64
#define helper_xvcvspsxds helper_xvcvspsxds_ppc64
#define helper_xvcvspsxws helper_xvcvspsxws_ppc64
#define helper_xvcvspuxds helper_xvcvspuxds_ppc64
#define helper_xvcvspuxws helper_xvcvspuxws_ppc64
#define helper_xscvqpsdz helper_xscvqpsdz_ppc64
#define helper_xscvqpswz helper_xscvqpswz_ppc64
#define helper_xscvqpudz helper_xscvqpudz_ppc64
#define helper_xscvqpuwz helper_xscvqpuwz_ppc64
#define helper_xscvsxddp helper_xscvsxddp_ppc64
#define helper_xscvuxddp helper_xscvuxddp_ppc64
#define helper_xscvsxdsp helper_xscvsxdsp_ppc64
#define helper_xscvuxdsp helper_xscvuxdsp_ppc64
#define helper_xvcvsxddp helper_xvcvsxddp_ppc64
#define helper_xvcvuxddp helper_xvcvuxddp_ppc64
#define helper_xvcvsxwdp helper_xvcvsxwdp_ppc64
#define helper_xvcvuxwdp helper_xvcvuxwdp_ppc64
#define helper_xvcvsxdsp helper_xvcvsxdsp_ppc64
#define helper_xvcvuxdsp helper_xvcvuxdsp_ppc64
#define helper_xvcvsxwsp helper_xvcvsxwsp_ppc64
#define helper_xvcvuxwsp helper_xvcvuxwsp_ppc64
#define helper_xscvsdqp helper_xscvsdqp_ppc64
#define helper_xscvudqp helper_xscvudqp_ppc64
#define helper_xsrdpi helper_xsrdpi_ppc64
#define helper_xsrdpic helper_xsrdpic_ppc64
#define helper_xsrdpim helper_xsrdpim_ppc64
#define helper_xsrdpip helper_xsrdpip_ppc64
#define helper_xsrdpiz helper_xsrdpiz_ppc64
#define helper_xvrdpi helper_xvrdpi_ppc64
#define helper_xvrdpic helper_xvrdpic_ppc64
#define helper_xvrdpim helper_xvrdpim_ppc64
#define helper_xvrdpip helper_xvrdpip_ppc64
#define helper_xvrdpiz helper_xvrdpiz_ppc64
#define helper_xvrspi helper_xvrspi_ppc64
#define helper_xvrspic helper_xvrspic_ppc64
#define helper_xvrspim helper_xvrspim_ppc64
#define helper_xvrspip helper_xvrspip_ppc64
#define helper_xvrspiz helper_xvrspiz_ppc64
#define helper_xsrsp helper_xsrsp_ppc64
#define helper_xxperm helper_xxperm_ppc64
#define helper_xxpermr helper_xxpermr_ppc64
#define helper_xvxsigsp helper_xvxsigsp_ppc64
#define helper_xvtstdcdp helper_xvtstdcdp_ppc64
#define helper_xvtstdcsp helper_xvtstdcsp_ppc64
#define helper_xststdcdp helper_xststdcdp_ppc64
#define helper_xststdcqp helper_xststdcqp_ppc64
#define helper_xststdcsp helper_xststdcsp_ppc64
#define helper_xsrqpi helper_xsrqpi_ppc64
#define helper_xsrqpxp helper_xsrqpxp_ppc64
#define helper_xssqrtqp helper_xssqrtqp_ppc64
#define helper_xssubqp helper_xssubqp_ppc64
#define do_store_fpscr do_store_fpscr_ppc64
#endif
